# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetConnectionTicketResponseBody(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        app_instance_id: str = None,
        app_instance_persistent_id: str = None,
        avatar_id: str = None,
        biz_region_id: str = None,
        os_type: str = None,
        request_id: str = None,
        task_id: str = None,
        task_status: str = None,
        tenant_id: int = None,
        ticket: str = None,
    ):
        # The ID of the delivery group.
        self.app_instance_group_id = app_instance_group_id
        # The ID of the application instance.
        self.app_instance_id = app_instance_id
        # The ID of the persistent session.
        self.app_instance_persistent_id = app_instance_persistent_id
        # The avatar ID.
        self.avatar_id = avatar_id
        # The region ID.
        self.biz_region_id = biz_region_id
        # The operating system.
        # 
        # Valid value:
        # 
        # *   Windows: the Windows operating system
        self.os_type = os_type
        # The request ID.
        self.request_id = request_id
        # The task ID.
        self.task_id = task_id
        # The task status.
        # 
        # Valid values:
        # 
        # *   Finished: The task is complete.
        # *   Failed: The task failed.
        # *   Running: The task is being executed.
        self.task_status = task_status
        # The ID of the Alibaba Cloud account.
        self.tenant_id = tenant_id
        # The credential that is used to connect to App Streaming.
        # 
        # >  This parameter is displayed for calls other than the first call to this operation.
        self.ticket = ticket

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.app_instance_id is not None:
            result['AppInstanceId'] = self.app_instance_id

        if self.app_instance_persistent_id is not None:
            result['AppInstancePersistentId'] = self.app_instance_persistent_id

        if self.avatar_id is not None:
            result['AvatarId'] = self.avatar_id

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_status is not None:
            result['TaskStatus'] = self.task_status

        if self.tenant_id is not None:
            result['TenantId'] = self.tenant_id

        if self.ticket is not None:
            result['Ticket'] = self.ticket

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AppInstanceId') is not None:
            self.app_instance_id = m.get('AppInstanceId')

        if m.get('AppInstancePersistentId') is not None:
            self.app_instance_persistent_id = m.get('AppInstancePersistentId')

        if m.get('AvatarId') is not None:
            self.avatar_id = m.get('AvatarId')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskStatus') is not None:
            self.task_status = m.get('TaskStatus')

        if m.get('TenantId') is not None:
            self.tenant_id = m.get('TenantId')

        if m.get('Ticket') is not None:
            self.ticket = m.get('Ticket')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class RenewWuyingServerRequest(DaraModel):
    def __init__(
        self,
        auto_pay: bool = None,
        period: int = None,
        period_unit: str = None,
        promotion_id: str = None,
        wuying_server_id: str = None,
    ):
        # Automatic payment.
        self.auto_pay = auto_pay
        # The renewal duration.
        self.period = period
        # The unit of the renewal time.
        # 
        # Valid values:
        # 
        # *   Month: month.
        # *   Year: year.
        self.period_unit = period_unit
        # The discount ID.
        self.promotion_id = promotion_id
        # The ID of the workstation.
        self.wuying_server_id = wuying_server_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.period is not None:
            result['Period'] = self.period

        if self.period_unit is not None:
            result['PeriodUnit'] = self.period_unit

        if self.promotion_id is not None:
            result['PromotionId'] = self.promotion_id

        if self.wuying_server_id is not None:
            result['WuyingServerId'] = self.wuying_server_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('Period') is not None:
            self.period = m.get('Period')

        if m.get('PeriodUnit') is not None:
            self.period_unit = m.get('PeriodUnit')

        if m.get('PromotionId') is not None:
            self.promotion_id = m.get('PromotionId')

        if m.get('WuyingServerId') is not None:
            self.wuying_server_id = m.get('WuyingServerId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class RenewAppInstanceGroupShrinkRequest(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        auto_pay: bool = None,
        period: int = None,
        period_unit: str = None,
        product_type: str = None,
        promotion_id: str = None,
        renew_amount: int = None,
        renew_mode: str = None,
        renew_nodes_shrink: str = None,
    ):
        # The ID of the delivery group.
        # 
        # This parameter is required.
        self.app_instance_group_id = app_instance_group_id
        # Specifies whether to enable automatic payment.
        # 
        # Valid values:
        # 
        # *   true
        # *   false: manual payment. This is the default value.
        self.auto_pay = auto_pay
        # The subscription duration of resources. This parameter must be configured together with `PeriodUnit`.
        # 
        # This parameter is required.
        self.period = period
        # The unit of the subscription duration. This parameter must be configured together with `Period`. The following items describe valid values for the combinations of `Period` and `PeriodUnit`:
        # 
        # *   1 Week
        # *   1 Month
        # *   2 Month
        # *   3 Month
        # *   6 Month
        # *   1 Year
        # *   2 Year
        # *   3 Year
        # 
        # >  The value of this parameter is case-insensitive. For example, `Week` is valid and `week` is invalid. If you specify a value combination other than the preceding combinations, such as `2 Week`, the operation can still be called. However, an error occurs when you place the order.
        # 
        # This parameter is required.
        self.period_unit = period_unit
        # The product type.
        # 
        # Valid value:
        # 
        # *   CloudApp: App Streaming
        # 
        # This parameter is required.
        self.product_type = product_type
        # The promotion ID. You can call the [GetResourcePrice](https://help.aliyun.com/document_detail/428503.html) operation to obtain the ID.
        self.promotion_id = promotion_id
        self.renew_amount = renew_amount
        self.renew_mode = renew_mode
        self.renew_nodes_shrink = renew_nodes_shrink

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.period is not None:
            result['Period'] = self.period

        if self.period_unit is not None:
            result['PeriodUnit'] = self.period_unit

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.promotion_id is not None:
            result['PromotionId'] = self.promotion_id

        if self.renew_amount is not None:
            result['RenewAmount'] = self.renew_amount

        if self.renew_mode is not None:
            result['RenewMode'] = self.renew_mode

        if self.renew_nodes_shrink is not None:
            result['RenewNodes'] = self.renew_nodes_shrink

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('Period') is not None:
            self.period = m.get('Period')

        if m.get('PeriodUnit') is not None:
            self.period_unit = m.get('PeriodUnit')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('PromotionId') is not None:
            self.promotion_id = m.get('PromotionId')

        if m.get('RenewAmount') is not None:
            self.renew_amount = m.get('RenewAmount')

        if m.get('RenewMode') is not None:
            self.renew_mode = m.get('RenewMode')

        if m.get('RenewNodes') is not None:
            self.renew_nodes_shrink = m.get('RenewNodes')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._approve_ota_task_request import ApproveOtaTaskRequest
from ._approve_ota_task_response_body import ApproveOtaTaskResponseBody
from ._approve_ota_task_response import ApproveOtaTaskResponse
from ._authorize_instance_group_request import AuthorizeInstanceGroupRequest
from ._authorize_instance_group_shrink_request import AuthorizeInstanceGroupShrinkRequest
from ._authorize_instance_group_response_body import AuthorizeInstanceGroupResponseBody
from ._authorize_instance_group_response import AuthorizeInstanceGroupResponse
from ._create_app_instance_group_request import CreateAppInstanceGroupRequest
from ._create_app_instance_group_shrink_request import CreateAppInstanceGroupShrinkRequest
from ._create_app_instance_group_response_body import CreateAppInstanceGroupResponseBody
from ._create_app_instance_group_response import CreateAppInstanceGroupResponse
from ._create_image_by_instance_request import CreateImageByInstanceRequest
from ._create_image_by_instance_response_body import CreateImageByInstanceResponseBody
from ._create_image_by_instance_response import CreateImageByInstanceResponse
from ._create_image_from_app_instance_group_request import CreateImageFromAppInstanceGroupRequest
from ._create_image_from_app_instance_group_response_body import CreateImageFromAppInstanceGroupResponseBody
from ._create_image_from_app_instance_group_response import CreateImageFromAppInstanceGroupResponse
from ._create_wuying_server_request import CreateWuyingServerRequest
from ._create_wuying_server_response_body import CreateWuyingServerResponseBody
from ._create_wuying_server_response import CreateWuyingServerResponse
from ._delete_app_instance_group_request import DeleteAppInstanceGroupRequest
from ._delete_app_instance_group_response_body import DeleteAppInstanceGroupResponseBody
from ._delete_app_instance_group_response import DeleteAppInstanceGroupResponse
from ._delete_app_instances_request import DeleteAppInstancesRequest
from ._delete_app_instances_response_body import DeleteAppInstancesResponseBody
from ._delete_app_instances_response import DeleteAppInstancesResponse
from ._delete_image_request import DeleteImageRequest
from ._delete_image_response_body import DeleteImageResponseBody
from ._delete_image_response import DeleteImageResponse
from ._delete_wuying_server_request import DeleteWuyingServerRequest
from ._delete_wuying_server_response_body import DeleteWuyingServerResponseBody
from ._delete_wuying_server_response import DeleteWuyingServerResponse
from ._describe_wuying_server_eip_info_request import DescribeWuyingServerEipInfoRequest
from ._describe_wuying_server_eip_info_response_body import DescribeWuyingServerEipInfoResponseBody
from ._describe_wuying_server_eip_info_response import DescribeWuyingServerEipInfoResponse
from ._get_app_instance_group_request import GetAppInstanceGroupRequest
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBody
from ._get_app_instance_group_response import GetAppInstanceGroupResponse
from ._get_connection_ticket_request import GetConnectionTicketRequest
from ._get_connection_ticket_response_body import GetConnectionTicketResponseBody
from ._get_connection_ticket_response import GetConnectionTicketResponse
from ._get_debug_app_instance_request import GetDebugAppInstanceRequest
from ._get_debug_app_instance_response_body import GetDebugAppInstanceResponseBody
from ._get_debug_app_instance_response import GetDebugAppInstanceResponse
from ._get_ota_task_by_task_id_request import GetOtaTaskByTaskIdRequest
from ._get_ota_task_by_task_id_response_body import GetOtaTaskByTaskIdResponseBody
from ._get_ota_task_by_task_id_response import GetOtaTaskByTaskIdResponse
from ._get_resource_price_request import GetResourcePriceRequest
from ._get_resource_price_response_body import GetResourcePriceResponseBody
from ._get_resource_price_response import GetResourcePriceResponse
from ._get_resource_renew_price_request import GetResourceRenewPriceRequest
from ._get_resource_renew_price_response_body import GetResourceRenewPriceResponseBody
from ._get_resource_renew_price_response import GetResourceRenewPriceResponse
from ._list_app_instance_group_request import ListAppInstanceGroupRequest
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBody
from ._list_app_instance_group_response import ListAppInstanceGroupResponse
from ._list_app_instances_request import ListAppInstancesRequest
from ._list_app_instances_response_body import ListAppInstancesResponseBody
from ._list_app_instances_response import ListAppInstancesResponse
from ._list_authorized_user_groups_request import ListAuthorizedUserGroupsRequest
from ._list_authorized_user_groups_response_body import ListAuthorizedUserGroupsResponseBody
from ._list_authorized_user_groups_response import ListAuthorizedUserGroupsResponse
from ._list_bind_info_request import ListBindInfoRequest
from ._list_bind_info_response_body import ListBindInfoResponseBody
from ._list_bind_info_response import ListBindInfoResponse
from ._list_image_request import ListImageRequest
from ._list_image_response_body import ListImageResponseBody
from ._list_image_response import ListImageResponse
from ._list_node_instance_type_request import ListNodeInstanceTypeRequest
from ._list_node_instance_type_response_body import ListNodeInstanceTypeResponseBody
from ._list_node_instance_type_response import ListNodeInstanceTypeResponse
from ._list_nodes_request import ListNodesRequest
from ._list_nodes_response_body import ListNodesResponseBody
from ._list_nodes_response import ListNodesResponse
from ._list_ota_task_request import ListOtaTaskRequest
from ._list_ota_task_response_body import ListOtaTaskResponseBody
from ._list_ota_task_response import ListOtaTaskResponse
from ._list_persistent_app_instances_request import ListPersistentAppInstancesRequest
from ._list_persistent_app_instances_response_body import ListPersistentAppInstancesResponseBody
from ._list_persistent_app_instances_response import ListPersistentAppInstancesResponse
from ._list_regions_request import ListRegionsRequest
from ._list_regions_response_body import ListRegionsResponseBody
from ._list_regions_response import ListRegionsResponse
from ._list_tag_cloud_resources_request import ListTagCloudResourcesRequest
from ._list_tag_cloud_resources_response_body import ListTagCloudResourcesResponseBody
from ._list_tag_cloud_resources_response import ListTagCloudResourcesResponse
from ._list_tenant_config_response_body import ListTenantConfigResponseBody
from ._list_tenant_config_response import ListTenantConfigResponse
from ._list_wuying_server_request import ListWuyingServerRequest
from ._list_wuying_server_response_body import ListWuyingServerResponseBody
from ._list_wuying_server_response import ListWuyingServerResponse
from ._log_off_all_sessions_in_app_instance_group_request import LogOffAllSessionsInAppInstanceGroupRequest
from ._log_off_all_sessions_in_app_instance_group_response_body import LogOffAllSessionsInAppInstanceGroupResponseBody
from ._log_off_all_sessions_in_app_instance_group_response import LogOffAllSessionsInAppInstanceGroupResponse
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequest
from ._modify_app_instance_group_attribute_shrink_request import ModifyAppInstanceGroupAttributeShrinkRequest
from ._modify_app_instance_group_attribute_response_body import ModifyAppInstanceGroupAttributeResponseBody
from ._modify_app_instance_group_attribute_response import ModifyAppInstanceGroupAttributeResponse
from ._modify_app_policy_request import ModifyAppPolicyRequest
from ._modify_app_policy_shrink_request import ModifyAppPolicyShrinkRequest
from ._modify_app_policy_response_body import ModifyAppPolicyResponseBody
from ._modify_app_policy_response import ModifyAppPolicyResponse
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequest
from ._modify_browser_instance_group_shrink_request import ModifyBrowserInstanceGroupShrinkRequest
from ._modify_browser_instance_group_response_body import ModifyBrowserInstanceGroupResponseBody
from ._modify_browser_instance_group_response import ModifyBrowserInstanceGroupResponse
from ._modify_node_pool_amount_request import ModifyNodePoolAmountRequest
from ._modify_node_pool_amount_shrink_request import ModifyNodePoolAmountShrinkRequest
from ._modify_node_pool_amount_response_body import ModifyNodePoolAmountResponseBody
from ._modify_node_pool_amount_response import ModifyNodePoolAmountResponse
from ._modify_node_pool_attribute_request import ModifyNodePoolAttributeRequest
from ._modify_node_pool_attribute_shrink_request import ModifyNodePoolAttributeShrinkRequest
from ._modify_node_pool_attribute_response_body import ModifyNodePoolAttributeResponseBody
from ._modify_node_pool_attribute_response import ModifyNodePoolAttributeResponse
from ._modify_tenant_config_request import ModifyTenantConfigRequest
from ._modify_tenant_config_response_body import ModifyTenantConfigResponseBody
from ._modify_tenant_config_response import ModifyTenantConfigResponse
from ._modify_wuying_server_attribute_request import ModifyWuyingServerAttributeRequest
from ._modify_wuying_server_attribute_response_body import ModifyWuyingServerAttributeResponseBody
from ._modify_wuying_server_attribute_response import ModifyWuyingServerAttributeResponse
from ._page_list_app_instance_group_user_request import PageListAppInstanceGroupUserRequest
from ._page_list_app_instance_group_user_response_body import PageListAppInstanceGroupUserResponseBody
from ._page_list_app_instance_group_user_response import PageListAppInstanceGroupUserResponse
from ._renew_app_instance_group_request import RenewAppInstanceGroupRequest
from ._renew_app_instance_group_shrink_request import RenewAppInstanceGroupShrinkRequest
from ._renew_app_instance_group_response_body import RenewAppInstanceGroupResponseBody
from ._renew_app_instance_group_response import RenewAppInstanceGroupResponse
from ._renew_wuying_server_request import RenewWuyingServerRequest
from ._renew_wuying_server_response_body import RenewWuyingServerResponseBody
from ._renew_wuying_server_response import RenewWuyingServerResponse
from ._restart_wuying_server_request import RestartWuyingServerRequest
from ._restart_wuying_server_response_body import RestartWuyingServerResponseBody
from ._restart_wuying_server_response import RestartWuyingServerResponse
from ._start_task_for_distribute_image_request import StartTaskForDistributeImageRequest
from ._start_task_for_distribute_image_response_body import StartTaskForDistributeImageResponseBody
from ._start_task_for_distribute_image_response import StartTaskForDistributeImageResponse
from ._start_wuying_server_request import StartWuyingServerRequest
from ._start_wuying_server_response_body import StartWuyingServerResponseBody
from ._start_wuying_server_response import StartWuyingServerResponse
from ._stop_wuying_server_request import StopWuyingServerRequest
from ._stop_wuying_server_response_body import StopWuyingServerResponseBody
from ._stop_wuying_server_response import StopWuyingServerResponse
from ._tag_cloud_resources_request import TagCloudResourcesRequest
from ._tag_cloud_resources_response_body import TagCloudResourcesResponseBody
from ._tag_cloud_resources_response import TagCloudResourcesResponse
from ._unbind_request import UnbindRequest
from ._unbind_response_body import UnbindResponseBody
from ._unbind_response import UnbindResponse
from ._untag_cloud_resources_request import UntagCloudResourcesRequest
from ._untag_cloud_resources_response_body import UntagCloudResourcesResponseBody
from ._untag_cloud_resources_response import UntagCloudResourcesResponse
from ._update_app_instance_group_image_request import UpdateAppInstanceGroupImageRequest
from ._update_app_instance_group_image_response_body import UpdateAppInstanceGroupImageResponseBody
from ._update_app_instance_group_image_response import UpdateAppInstanceGroupImageResponse
from ._update_wuying_server_image_request import UpdateWuyingServerImageRequest
from ._update_wuying_server_image_response_body import UpdateWuyingServerImageResponseBody
from ._update_wuying_server_image_response import UpdateWuyingServerImageResponse
from ._authorize_instance_group_request import AuthorizeInstanceGroupRequestUserMeta
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNetworkDomainRules
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNetworkRoutes
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNetwork
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNodePoolRecurrenceSchedulesTimerPeriods
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNodePoolRecurrenceSchedules
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestNodePool
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestRuntimePolicy
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestSecurityPolicy
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestStoragePolicyUserProfile
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestStoragePolicy
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestUserDefinePolicy
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestUserInfo
from ._create_app_instance_group_request import CreateAppInstanceGroupRequestVideoPolicy
from ._create_app_instance_group_response_body import CreateAppInstanceGroupResponseBodyAppInstanceGroupModel
from ._create_image_by_instance_response_body import CreateImageByInstanceResponseBodyData
from ._create_wuying_server_request import CreateWuyingServerRequestDataDisk
from ._create_wuying_server_response_body import CreateWuyingServerResponseBodyData
from ._delete_app_instances_response_body import DeleteAppInstancesResponseBodyDeleteAppInstanceModels
from ._describe_wuying_server_eip_info_response_body import DescribeWuyingServerEipInfoResponseBodyEipInfoModel
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsApps
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModelsTags
from ._get_app_instance_group_response_body import GetAppInstanceGroupResponseBodyAppInstanceGroupModels
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceListPricePromotions
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceListPrice
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceListRules
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceList
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceModelPricePromotions
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceModelPrice
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceModelRules
from ._get_resource_price_response_body import GetResourcePriceResponseBodyPriceModel
from ._get_resource_renew_price_response_body import GetResourceRenewPriceResponseBodyDataPricePromotions
from ._get_resource_renew_price_response_body import GetResourceRenewPriceResponseBodyDataPrice
from ._get_resource_renew_price_response_body import GetResourceRenewPriceResponseBodyDataRules
from ._get_resource_renew_price_response_body import GetResourceRenewPriceResponseBodyData
from ._list_app_instance_group_request import ListAppInstanceGroupRequestTag
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsApps
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsResourceTags
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModelsTags
from ._list_app_instance_group_response_body import ListAppInstanceGroupResponseBodyAppInstanceGroupModels
from ._list_app_instances_response_body import ListAppInstancesResponseBodyAppInstanceModelsBindInfo
from ._list_app_instances_response_body import ListAppInstancesResponseBodyAppInstanceModels
from ._list_authorized_user_groups_response_body import ListAuthorizedUserGroupsResponseBodyUserGroups
from ._list_bind_info_response_body import ListBindInfoResponseBodyBindInfoModels
from ._list_image_request import ListImageRequestTagList
from ._list_image_response_body import ListImageResponseBodyDataAppList
from ._list_image_response_body import ListImageResponseBodyDataImageRegionDistributeList
from ._list_image_response_body import ListImageResponseBodyData
from ._list_node_instance_type_response_body import ListNodeInstanceTypeResponseBodyNodeInstanceTypeModels
from ._list_nodes_response_body import ListNodesResponseBodyNodeModels
from ._list_ota_task_response_body import ListOtaTaskResponseBodyTaskList
from ._list_persistent_app_instances_response_body import ListPersistentAppInstancesResponseBodyPersistentAppInstanceModels
from ._list_regions_response_body import ListRegionsResponseBodyRegionModels
from ._list_tag_cloud_resources_response_body import ListTagCloudResourcesResponseBodyResourceTagsTags
from ._list_tag_cloud_resources_response_body import ListTagCloudResourcesResponseBodyResourceTags
from ._list_tenant_config_response_body import ListTenantConfigResponseBodyTenantConfigModel
from ._list_wuying_server_response_body import ListWuyingServerResponseBodyWuyingServerListDataDisk
from ._list_wuying_server_response_body import ListWuyingServerResponseBodyWuyingServerListInstanceInfoList
from ._list_wuying_server_response_body import ListWuyingServerResponseBodyWuyingServerListServerInstanceTypeInfo
from ._list_wuying_server_response_body import ListWuyingServerResponseBodyWuyingServerList
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestNetworkDomainRules
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestNetwork
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestNodePool
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestSecurityPolicy
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestStoragePolicyUserProfile
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestStoragePolicyUserProfileFollow
from ._modify_app_instance_group_attribute_request import ModifyAppInstanceGroupAttributeRequestStoragePolicy
from ._modify_app_policy_request import ModifyAppPolicyRequestVideoPolicy
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestBrowserConfigBookmarks
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestBrowserConfig
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestNetworkRestrictedURLs
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestNetwork
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestPolicyClipboardPolicy
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestPolicyVideoPolicy
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestPolicyWatermarkPolicy
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestPolicy
from ._modify_browser_instance_group_request import ModifyBrowserInstanceGroupRequestTimers
from ._modify_node_pool_amount_request import ModifyNodePoolAmountRequestNodePool
from ._modify_node_pool_amount_response_body import ModifyNodePoolAmountResponseBodyData
from ._modify_node_pool_attribute_request import ModifyNodePoolAttributeRequestNodePoolStrategyRecurrenceSchedulesTimerPeriods
from ._modify_node_pool_attribute_request import ModifyNodePoolAttributeRequestNodePoolStrategyRecurrenceSchedules
from ._modify_node_pool_attribute_request import ModifyNodePoolAttributeRequestNodePoolStrategy
from ._tag_cloud_resources_request import TagCloudResourcesRequestTags
from ._tag_cloud_resources_response_body import TagCloudResourcesResponseBodyFailedResourcesTags
from ._tag_cloud_resources_response_body import TagCloudResourcesResponseBodyFailedResources
from ._untag_cloud_resources_response_body import UntagCloudResourcesResponseBodyFailedResourcesTags
from ._untag_cloud_resources_response_body import UntagCloudResourcesResponseBodyFailedResources

__all__ = [
    ApproveOtaTaskRequest,
    ApproveOtaTaskResponseBody,
    ApproveOtaTaskResponse,
    AuthorizeInstanceGroupRequest,
    AuthorizeInstanceGroupShrinkRequest,
    AuthorizeInstanceGroupResponseBody,
    AuthorizeInstanceGroupResponse,
    CreateAppInstanceGroupRequest,
    CreateAppInstanceGroupShrinkRequest,
    CreateAppInstanceGroupResponseBody,
    CreateAppInstanceGroupResponse,
    CreateImageByInstanceRequest,
    CreateImageByInstanceResponseBody,
    CreateImageByInstanceResponse,
    CreateImageFromAppInstanceGroupRequest,
    CreateImageFromAppInstanceGroupResponseBody,
    CreateImageFromAppInstanceGroupResponse,
    CreateWuyingServerRequest,
    CreateWuyingServerResponseBody,
    CreateWuyingServerResponse,
    DeleteAppInstanceGroupRequest,
    DeleteAppInstanceGroupResponseBody,
    DeleteAppInstanceGroupResponse,
    DeleteAppInstancesRequest,
    DeleteAppInstancesResponseBody,
    DeleteAppInstancesResponse,
    DeleteImageRequest,
    DeleteImageResponseBody,
    DeleteImageResponse,
    DeleteWuyingServerRequest,
    DeleteWuyingServerResponseBody,
    DeleteWuyingServerResponse,
    DescribeWuyingServerEipInfoRequest,
    DescribeWuyingServerEipInfoResponseBody,
    DescribeWuyingServerEipInfoResponse,
    GetAppInstanceGroupRequest,
    GetAppInstanceGroupResponseBody,
    GetAppInstanceGroupResponse,
    GetConnectionTicketRequest,
    GetConnectionTicketResponseBody,
    GetConnectionTicketResponse,
    GetDebugAppInstanceRequest,
    GetDebugAppInstanceResponseBody,
    GetDebugAppInstanceResponse,
    GetOtaTaskByTaskIdRequest,
    GetOtaTaskByTaskIdResponseBody,
    GetOtaTaskByTaskIdResponse,
    GetResourcePriceRequest,
    GetResourcePriceResponseBody,
    GetResourcePriceResponse,
    GetResourceRenewPriceRequest,
    GetResourceRenewPriceResponseBody,
    GetResourceRenewPriceResponse,
    ListAppInstanceGroupRequest,
    ListAppInstanceGroupResponseBody,
    ListAppInstanceGroupResponse,
    ListAppInstancesRequest,
    ListAppInstancesResponseBody,
    ListAppInstancesResponse,
    ListAuthorizedUserGroupsRequest,
    ListAuthorizedUserGroupsResponseBody,
    ListAuthorizedUserGroupsResponse,
    ListBindInfoRequest,
    ListBindInfoResponseBody,
    ListBindInfoResponse,
    ListImageRequest,
    ListImageResponseBody,
    ListImageResponse,
    ListNodeInstanceTypeRequest,
    ListNodeInstanceTypeResponseBody,
    ListNodeInstanceTypeResponse,
    ListNodesRequest,
    ListNodesResponseBody,
    ListNodesResponse,
    ListOtaTaskRequest,
    ListOtaTaskResponseBody,
    ListOtaTaskResponse,
    ListPersistentAppInstancesRequest,
    ListPersistentAppInstancesResponseBody,
    ListPersistentAppInstancesResponse,
    ListRegionsRequest,
    ListRegionsResponseBody,
    ListRegionsResponse,
    ListTagCloudResourcesRequest,
    ListTagCloudResourcesResponseBody,
    ListTagCloudResourcesResponse,
    ListTenantConfigResponseBody,
    ListTenantConfigResponse,
    ListWuyingServerRequest,
    ListWuyingServerResponseBody,
    ListWuyingServerResponse,
    LogOffAllSessionsInAppInstanceGroupRequest,
    LogOffAllSessionsInAppInstanceGroupResponseBody,
    LogOffAllSessionsInAppInstanceGroupResponse,
    ModifyAppInstanceGroupAttributeRequest,
    ModifyAppInstanceGroupAttributeShrinkRequest,
    ModifyAppInstanceGroupAttributeResponseBody,
    ModifyAppInstanceGroupAttributeResponse,
    ModifyAppPolicyRequest,
    ModifyAppPolicyShrinkRequest,
    ModifyAppPolicyResponseBody,
    ModifyAppPolicyResponse,
    ModifyBrowserInstanceGroupRequest,
    ModifyBrowserInstanceGroupShrinkRequest,
    ModifyBrowserInstanceGroupResponseBody,
    ModifyBrowserInstanceGroupResponse,
    ModifyNodePoolAmountRequest,
    ModifyNodePoolAmountShrinkRequest,
    ModifyNodePoolAmountResponseBody,
    ModifyNodePoolAmountResponse,
    ModifyNodePoolAttributeRequest,
    ModifyNodePoolAttributeShrinkRequest,
    ModifyNodePoolAttributeResponseBody,
    ModifyNodePoolAttributeResponse,
    ModifyTenantConfigRequest,
    ModifyTenantConfigResponseBody,
    ModifyTenantConfigResponse,
    ModifyWuyingServerAttributeRequest,
    ModifyWuyingServerAttributeResponseBody,
    ModifyWuyingServerAttributeResponse,
    PageListAppInstanceGroupUserRequest,
    PageListAppInstanceGroupUserResponseBody,
    PageListAppInstanceGroupUserResponse,
    RenewAppInstanceGroupRequest,
    RenewAppInstanceGroupShrinkRequest,
    RenewAppInstanceGroupResponseBody,
    RenewAppInstanceGroupResponse,
    RenewWuyingServerRequest,
    RenewWuyingServerResponseBody,
    RenewWuyingServerResponse,
    RestartWuyingServerRequest,
    RestartWuyingServerResponseBody,
    RestartWuyingServerResponse,
    StartTaskForDistributeImageRequest,
    StartTaskForDistributeImageResponseBody,
    StartTaskForDistributeImageResponse,
    StartWuyingServerRequest,
    StartWuyingServerResponseBody,
    StartWuyingServerResponse,
    StopWuyingServerRequest,
    StopWuyingServerResponseBody,
    StopWuyingServerResponse,
    TagCloudResourcesRequest,
    TagCloudResourcesResponseBody,
    TagCloudResourcesResponse,
    UnbindRequest,
    UnbindResponseBody,
    UnbindResponse,
    UntagCloudResourcesRequest,
    UntagCloudResourcesResponseBody,
    UntagCloudResourcesResponse,
    UpdateAppInstanceGroupImageRequest,
    UpdateAppInstanceGroupImageResponseBody,
    UpdateAppInstanceGroupImageResponse,
    UpdateWuyingServerImageRequest,
    UpdateWuyingServerImageResponseBody,
    UpdateWuyingServerImageResponse,
    AuthorizeInstanceGroupRequestUserMeta,
    CreateAppInstanceGroupRequestNetworkDomainRules,
    CreateAppInstanceGroupRequestNetworkRoutes,
    CreateAppInstanceGroupRequestNetwork,
    CreateAppInstanceGroupRequestNodePoolRecurrenceSchedulesTimerPeriods,
    CreateAppInstanceGroupRequestNodePoolRecurrenceSchedules,
    CreateAppInstanceGroupRequestNodePool,
    CreateAppInstanceGroupRequestRuntimePolicy,
    CreateAppInstanceGroupRequestSecurityPolicy,
    CreateAppInstanceGroupRequestStoragePolicyUserProfile,
    CreateAppInstanceGroupRequestStoragePolicy,
    CreateAppInstanceGroupRequestUserDefinePolicy,
    CreateAppInstanceGroupRequestUserInfo,
    CreateAppInstanceGroupRequestVideoPolicy,
    CreateAppInstanceGroupResponseBodyAppInstanceGroupModel,
    CreateImageByInstanceResponseBodyData,
    CreateWuyingServerRequestDataDisk,
    CreateWuyingServerResponseBodyData,
    DeleteAppInstancesResponseBodyDeleteAppInstanceModels,
    DescribeWuyingServerEipInfoResponseBodyEipInfoModel,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsApps,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModelsTags,
    GetAppInstanceGroupResponseBodyAppInstanceGroupModels,
    GetResourcePriceResponseBodyPriceListPricePromotions,
    GetResourcePriceResponseBodyPriceListPrice,
    GetResourcePriceResponseBodyPriceListRules,
    GetResourcePriceResponseBodyPriceList,
    GetResourcePriceResponseBodyPriceModelPricePromotions,
    GetResourcePriceResponseBodyPriceModelPrice,
    GetResourcePriceResponseBodyPriceModelRules,
    GetResourcePriceResponseBodyPriceModel,
    GetResourceRenewPriceResponseBodyDataPricePromotions,
    GetResourceRenewPriceResponseBodyDataPrice,
    GetResourceRenewPriceResponseBodyDataRules,
    GetResourceRenewPriceResponseBodyData,
    ListAppInstanceGroupRequestTag,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsApps,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsResourceTags,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModelsTags,
    ListAppInstanceGroupResponseBodyAppInstanceGroupModels,
    ListAppInstancesResponseBodyAppInstanceModelsBindInfo,
    ListAppInstancesResponseBodyAppInstanceModels,
    ListAuthorizedUserGroupsResponseBodyUserGroups,
    ListBindInfoResponseBodyBindInfoModels,
    ListImageRequestTagList,
    ListImageResponseBodyDataAppList,
    ListImageResponseBodyDataImageRegionDistributeList,
    ListImageResponseBodyData,
    ListNodeInstanceTypeResponseBodyNodeInstanceTypeModels,
    ListNodesResponseBodyNodeModels,
    ListOtaTaskResponseBodyTaskList,
    ListPersistentAppInstancesResponseBodyPersistentAppInstanceModels,
    ListRegionsResponseBodyRegionModels,
    ListTagCloudResourcesResponseBodyResourceTagsTags,
    ListTagCloudResourcesResponseBodyResourceTags,
    ListTenantConfigResponseBodyTenantConfigModel,
    ListWuyingServerResponseBodyWuyingServerListDataDisk,
    ListWuyingServerResponseBodyWuyingServerListInstanceInfoList,
    ListWuyingServerResponseBodyWuyingServerListServerInstanceTypeInfo,
    ListWuyingServerResponseBodyWuyingServerList,
    ModifyAppInstanceGroupAttributeRequestNetworkDomainRules,
    ModifyAppInstanceGroupAttributeRequestNetwork,
    ModifyAppInstanceGroupAttributeRequestNodePool,
    ModifyAppInstanceGroupAttributeRequestSecurityPolicy,
    ModifyAppInstanceGroupAttributeRequestStoragePolicyUserProfile,
    ModifyAppInstanceGroupAttributeRequestStoragePolicyUserProfileFollow,
    ModifyAppInstanceGroupAttributeRequestStoragePolicy,
    ModifyAppPolicyRequestVideoPolicy,
    ModifyBrowserInstanceGroupRequestBrowserConfigBookmarks,
    ModifyBrowserInstanceGroupRequestBrowserConfig,
    ModifyBrowserInstanceGroupRequestNetworkRestrictedURLs,
    ModifyBrowserInstanceGroupRequestNetwork,
    ModifyBrowserInstanceGroupRequestPolicyClipboardPolicy,
    ModifyBrowserInstanceGroupRequestPolicyVideoPolicy,
    ModifyBrowserInstanceGroupRequestPolicyWatermarkPolicy,
    ModifyBrowserInstanceGroupRequestPolicy,
    ModifyBrowserInstanceGroupRequestTimers,
    ModifyNodePoolAmountRequestNodePool,
    ModifyNodePoolAmountResponseBodyData,
    ModifyNodePoolAttributeRequestNodePoolStrategyRecurrenceSchedulesTimerPeriods,
    ModifyNodePoolAttributeRequestNodePoolStrategyRecurrenceSchedules,
    ModifyNodePoolAttributeRequestNodePoolStrategy,
    TagCloudResourcesRequestTags,
    TagCloudResourcesResponseBodyFailedResourcesTags,
    TagCloudResourcesResponseBodyFailedResources,
    UntagCloudResourcesResponseBodyFailedResourcesTags,
    UntagCloudResourcesResponseBodyFailedResources
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class StartTaskForDistributeImageRequest(DaraModel):
    def __init__(
        self,
        destination_region_list: List[str] = None,
        image_id: str = None,
        product_type: str = None,
        retry_type: str = None,
        source_region: str = None,
        version_id: str = None,
    ):
        # The regions to which you want to replicate the image.
        self.destination_region_list = destination_region_list
        # The image ID.
        # 
        # This parameter is required.
        self.image_id = image_id
        # The product type.
        # 
        # Valid values:
        # 
        # *   CloudDesktop: Elastic Desktop Service
        # *   CloudApp: App Streaming
        # *   WuyingServer: Workstation
        self.product_type = product_type
        # This parameter is not publicly available.
        self.retry_type = retry_type
        # The region where the source image is located. If you leave this parameter empty, a random region is selected.
        self.source_region = source_region
        # The ID of the image version. If you do not specify this parameter, the latest image version is used by default.
        self.version_id = version_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.destination_region_list is not None:
            result['DestinationRegionList'] = self.destination_region_list

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.retry_type is not None:
            result['RetryType'] = self.retry_type

        if self.source_region is not None:
            result['SourceRegion'] = self.source_region

        if self.version_id is not None:
            result['VersionId'] = self.version_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DestinationRegionList') is not None:
            self.destination_region_list = m.get('DestinationRegionList')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('RetryType') is not None:
            self.retry_type = m.get('RetryType')

        if m.get('SourceRegion') is not None:
            self.source_region = m.get('SourceRegion')

        if m.get('VersionId') is not None:
            self.version_id = m.get('VersionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class TagCloudResourcesResponseBody(DaraModel):
    def __init__(
        self,
        failed_resources: List[main_models.TagCloudResourcesResponseBodyFailedResources] = None,
        request_id: str = None,
    ):
        # The cloud resources on which the operation failed and the corresponding tags.
        self.failed_resources = failed_resources
        self.request_id = request_id

    def validate(self):
        if self.failed_resources:
            for v1 in self.failed_resources:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['FailedResources'] = []
        if self.failed_resources is not None:
            for k1 in self.failed_resources:
                result['FailedResources'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.failed_resources = []
        if m.get('FailedResources') is not None:
            for k1 in m.get('FailedResources'):
                temp_model = main_models.TagCloudResourcesResponseBodyFailedResources()
                self.failed_resources.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class TagCloudResourcesResponseBodyFailedResources(DaraModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        resource_id: str = None,
        resource_type: str = None,
        tags: List[main_models.TagCloudResourcesResponseBodyFailedResourcesTags] = None,
    ):
        self.code = code
        self.message = message
        self.resource_id = resource_id
        # The type of the cloud resource.
        # 
        # Valid values:
        # 
        # *   CenterImageId: center image ID.
        # *   AppId: app ID.
        # *   WyId: Alibaba Cloud Workspace user ID.
        # *   AppInstanceGroupId: delivery group ID.
        # *   AliUid: tenant ID.
        self.resource_type = resource_type
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.message is not None:
            result['Message'] = self.message

        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.TagCloudResourcesResponseBodyFailedResourcesTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class TagCloudResourcesResponseBodyFailedResourcesTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        scope: str = None,
        value: str = None,
    ):
        self.key = key
        self.scope = scope
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.scope is not None:
            result['Scope'] = self.scope

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Scope') is not None:
            self.scope = m.get('Scope')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class CreateAppInstanceGroupRequest(DaraModel):
    def __init__(
        self,
        app_center_image_id: str = None,
        app_instance_group_name: str = None,
        app_package_type: str = None,
        app_policy_id: str = None,
        auth_mode: str = None,
        auto_pay: bool = None,
        auto_renew: bool = None,
        biz_region_id: str = None,
        charge_resource_mode: str = None,
        charge_type: str = None,
        cluster_id: str = None,
        network: main_models.CreateAppInstanceGroupRequestNetwork = None,
        node_pool: main_models.CreateAppInstanceGroupRequestNodePool = None,
        period: int = None,
        period_unit: str = None,
        pre_open_app_id: str = None,
        product_type: str = None,
        promotion_id: str = None,
        runtime_policy: main_models.CreateAppInstanceGroupRequestRuntimePolicy = None,
        security_policy: main_models.CreateAppInstanceGroupRequestSecurityPolicy = None,
        session_timeout: int = None,
        storage_policy: main_models.CreateAppInstanceGroupRequestStoragePolicy = None,
        sub_pay_type: str = None,
        user_define_policy: main_models.CreateAppInstanceGroupRequestUserDefinePolicy = None,
        user_group_ids: List[str] = None,
        user_info: main_models.CreateAppInstanceGroupRequestUserInfo = None,
        users: List[str] = None,
        video_policy: main_models.CreateAppInstanceGroupRequestVideoPolicy = None,
    ):
        # The image ID of the application. To obtain the image ID, log on to the [App Streaming console](https://appstreaming.console.aliyun.com/). In the left-side navigation pane, choose **Maintenance** > **Custom Images** or Maintenance > **System Images**.
        # 
        # This parameter is required.
        self.app_center_image_id = app_center_image_id
        # The name of the delivery group.
        self.app_instance_group_name = app_instance_group_name
        # Package type.
        self.app_package_type = app_package_type
        # Policy ID.
        self.app_policy_id = app_policy_id
        # The authentication mode of the delivery group.
        self.auth_mode = auth_mode
        # Specifies whether to enable automatic payment.
        # 
        # Valid values:
        # 
        # *   true
        # *   false: manual payment. This is the default value.
        self.auto_pay = auto_pay
        # Specifies whether to enable auto-renewal.
        # 
        # Valid values:
        # 
        # *   true
        # *   false: manual payment. This is the default value.
        self.auto_renew = auto_renew
        # The ID of the region where the delivery group resides. For information about the supported regions, see [Limits](https://help.aliyun.com/document_detail/426036.html).
        # 
        # Valid values:
        # 
        # *   cn-shanghai: China (Shanghai)
        # *   cn-hangzhou: China (Hangzhou)
        # 
        # This parameter is required.
        self.biz_region_id = biz_region_id
        # The sales mode.
        # 
        # Valid value:
        # 
        # *   Node: by resource
        # 
        # This parameter is required.
        self.charge_resource_mode = charge_resource_mode
        # The billing method.
        # 
        # Valid values:
        # 
        # *   PostPaid: pay-as-you-go
        # *   PrePaid: subscription
        # 
        # This parameter is required.
        self.charge_type = charge_type
        # Cluster ID.
        self.cluster_id = cluster_id
        # The network settings.
        # 
        # >  If you want to use this parameter, submit a ticket.
        self.network = network
        # The node pool object.
        self.node_pool = node_pool
        # The subscription duration of resources. This parameter is required if you set `ChargeType` to `PrePaid`. The unit of this parameter is specified by `PeriodUnit`.
        # 
        # *   Valid value if you set `PeriodUnit` to `Week`:
        # 
        #     *   1
        # 
        # *   Valid values if you set `PeriodUnit` to `Month`:
        # 
        #     *   1
        #     *   2
        #     *   3
        #     *   6
        # 
        # *   Valid values if you set `PeriodUnit` to `Year`:
        # 
        #     *   1
        #     *   2
        #     *   3
        # 
        # >  If you set `ChargeType` to `PostPaid`, set this parameter to 1.
        # 
        # This parameter is required.
        self.period = period
        # The unit of the subscription duration. This parameter is available if you set `ChargeType` to `PrePaid`.
        # 
        # >  The value of this parameter is case-insensitive. For example, `Week` is valid and `week` is invalid. If you specify an invalid value combination for Period and PeriodUnit, such as `2 Week`, the operation can still be called. However, an error occurs when you place the order.
        # 
        # >  If you set `ChargeType` to `PostPaid`, set this parameter to `Month`.
        # 
        # Valid values:
        # 
        # *   Month
        # *   Year
        # *   Week
        # 
        # This parameter is required.
        self.period_unit = period_unit
        # The ID of the pre-open application.
        self.pre_open_app_id = pre_open_app_id
        # The product type.
        # 
        # Valid value:
        # 
        # *   CloudApp: App Streaming
        # 
        # This parameter is required.
        self.product_type = product_type
        # The promotion ID. You can call the [GetResourcePrice](https://help.aliyun.com/document_detail/428503.html) operation to obtain the ID.
        self.promotion_id = promotion_id
        # The runtime policy.
        self.runtime_policy = runtime_policy
        # The security policy.
        self.security_policy = security_policy
        # The period of time during which the application can be recycled. The recycling period is the period of time between the time when the end user disconnects from the application and the time when processes exit the application. If you do not want to recycle the application, set this parameter to `-1`. Valid values:-1 and 3 to 300. The value must be an integer. Default value: `15`. Unit: minutes.
        # 
        # This parameter is required.
        self.session_timeout = session_timeout
        # The storage policy.
        self.storage_policy = storage_policy
        # Payment method subtype.
        self.sub_pay_type = sub_pay_type
        # The custom policy.
        self.user_define_policy = user_define_policy
        # List of authorized user group IDs.
        self.user_group_ids = user_group_ids
        # The information about the user that you want to add to the assigned user list of the delivery group. This parameter is required if you configure `Users`.
        self.user_info = user_info
        # The users that you want to add to the assigned user list of the delivery group.
        self.users = users
        # Display policy.
        self.video_policy = video_policy

    def validate(self):
        if self.network:
            self.network.validate()
        if self.node_pool:
            self.node_pool.validate()
        if self.runtime_policy:
            self.runtime_policy.validate()
        if self.security_policy:
            self.security_policy.validate()
        if self.storage_policy:
            self.storage_policy.validate()
        if self.user_define_policy:
            self.user_define_policy.validate()
        if self.user_info:
            self.user_info.validate()
        if self.video_policy:
            self.video_policy.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_center_image_id is not None:
            result['AppCenterImageId'] = self.app_center_image_id

        if self.app_instance_group_name is not None:
            result['AppInstanceGroupName'] = self.app_instance_group_name

        if self.app_package_type is not None:
            result['AppPackageType'] = self.app_package_type

        if self.app_policy_id is not None:
            result['AppPolicyId'] = self.app_policy_id

        if self.auth_mode is not None:
            result['AuthMode'] = self.auth_mode

        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.auto_renew is not None:
            result['AutoRenew'] = self.auto_renew

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.charge_resource_mode is not None:
            result['ChargeResourceMode'] = self.charge_resource_mode

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        if self.cluster_id is not None:
            result['ClusterId'] = self.cluster_id

        if self.network is not None:
            result['Network'] = self.network.to_map()

        if self.node_pool is not None:
            result['NodePool'] = self.node_pool.to_map()

        if self.period is not None:
            result['Period'] = self.period

        if self.period_unit is not None:
            result['PeriodUnit'] = self.period_unit

        if self.pre_open_app_id is not None:
            result['PreOpenAppId'] = self.pre_open_app_id

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.promotion_id is not None:
            result['PromotionId'] = self.promotion_id

        if self.runtime_policy is not None:
            result['RuntimePolicy'] = self.runtime_policy.to_map()

        if self.security_policy is not None:
            result['SecurityPolicy'] = self.security_policy.to_map()

        if self.session_timeout is not None:
            result['SessionTimeout'] = self.session_timeout

        if self.storage_policy is not None:
            result['StoragePolicy'] = self.storage_policy.to_map()

        if self.sub_pay_type is not None:
            result['SubPayType'] = self.sub_pay_type

        if self.user_define_policy is not None:
            result['UserDefinePolicy'] = self.user_define_policy.to_map()

        if self.user_group_ids is not None:
            result['UserGroupIds'] = self.user_group_ids

        if self.user_info is not None:
            result['UserInfo'] = self.user_info.to_map()

        if self.users is not None:
            result['Users'] = self.users

        if self.video_policy is not None:
            result['VideoPolicy'] = self.video_policy.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppCenterImageId') is not None:
            self.app_center_image_id = m.get('AppCenterImageId')

        if m.get('AppInstanceGroupName') is not None:
            self.app_instance_group_name = m.get('AppInstanceGroupName')

        if m.get('AppPackageType') is not None:
            self.app_package_type = m.get('AppPackageType')

        if m.get('AppPolicyId') is not None:
            self.app_policy_id = m.get('AppPolicyId')

        if m.get('AuthMode') is not None:
            self.auth_mode = m.get('AuthMode')

        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('AutoRenew') is not None:
            self.auto_renew = m.get('AutoRenew')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('ChargeResourceMode') is not None:
            self.charge_resource_mode = m.get('ChargeResourceMode')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        if m.get('ClusterId') is not None:
            self.cluster_id = m.get('ClusterId')

        if m.get('Network') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestNetwork()
            self.network = temp_model.from_map(m.get('Network'))

        if m.get('NodePool') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestNodePool()
            self.node_pool = temp_model.from_map(m.get('NodePool'))

        if m.get('Period') is not None:
            self.period = m.get('Period')

        if m.get('PeriodUnit') is not None:
            self.period_unit = m.get('PeriodUnit')

        if m.get('PreOpenAppId') is not None:
            self.pre_open_app_id = m.get('PreOpenAppId')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('PromotionId') is not None:
            self.promotion_id = m.get('PromotionId')

        if m.get('RuntimePolicy') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestRuntimePolicy()
            self.runtime_policy = temp_model.from_map(m.get('RuntimePolicy'))

        if m.get('SecurityPolicy') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestSecurityPolicy()
            self.security_policy = temp_model.from_map(m.get('SecurityPolicy'))

        if m.get('SessionTimeout') is not None:
            self.session_timeout = m.get('SessionTimeout')

        if m.get('StoragePolicy') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestStoragePolicy()
            self.storage_policy = temp_model.from_map(m.get('StoragePolicy'))

        if m.get('SubPayType') is not None:
            self.sub_pay_type = m.get('SubPayType')

        if m.get('UserDefinePolicy') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestUserDefinePolicy()
            self.user_define_policy = temp_model.from_map(m.get('UserDefinePolicy'))

        if m.get('UserGroupIds') is not None:
            self.user_group_ids = m.get('UserGroupIds')

        if m.get('UserInfo') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestUserInfo()
            self.user_info = temp_model.from_map(m.get('UserInfo'))

        if m.get('Users') is not None:
            self.users = m.get('Users')

        if m.get('VideoPolicy') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestVideoPolicy()
            self.video_policy = temp_model.from_map(m.get('VideoPolicy'))

        return self

class CreateAppInstanceGroupRequestVideoPolicy(DaraModel):
    def __init__(
        self,
        frame_rate: int = None,
        session_resolution_height: int = None,
        session_resolution_width: int = None,
        streaming_mode: str = None,
        terminal_resolution_adaptive: bool = None,
        webrtc: bool = None,
    ):
        # Frame rate (FPS).
        self.frame_rate = frame_rate
        # Resolution height, in pixels.
        self.session_resolution_height = session_resolution_height
        # Resolution width, in pixels.
        self.session_resolution_width = session_resolution_width
        # Streaming mode. Combined with the Webrtc parameter, it indicates the protocol type.
        # 
        # - When Webrtc=true and StreamingMode=video, it indicates a WebRTC stream.
        # - When Webrtc=false and StreamingMode=video, it indicates a video stream.
        # - When Webrtc=false and StreamingMode=mix, it indicates a mixed stream.
        self.streaming_mode = streaming_mode
        # Whether to use adaptive resolution.
        # 
        # - true: The session resolution follows changes in the terminal\\"s display area. In this case, SessionResolutionWidth and SessionResolutionHeight represent the maximum values for resolution adjustment.
        # 
        # - false: The session resolution does not follow changes in the terminal\\"s display area. In this case, the resolution is fixed to the values of SessionResolutionWidth and SessionResolutionHeight.
        self.terminal_resolution_adaptive = terminal_resolution_adaptive
        # Whether to enable WebRTC. Combined with the StreamingMode parameter, it indicates the protocol type.
        # 
        # - When Webrtc=true and StreamingMode=video, it indicates a WebRTC stream.
        # - When Webrtc=false and StreamingMode=video, it indicates a video stream.
        # - When Webrtc=false and StreamingMode=mix, it indicates a mixed stream.
        self.webrtc = webrtc

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.frame_rate is not None:
            result['FrameRate'] = self.frame_rate

        if self.session_resolution_height is not None:
            result['SessionResolutionHeight'] = self.session_resolution_height

        if self.session_resolution_width is not None:
            result['SessionResolutionWidth'] = self.session_resolution_width

        if self.streaming_mode is not None:
            result['StreamingMode'] = self.streaming_mode

        if self.terminal_resolution_adaptive is not None:
            result['TerminalResolutionAdaptive'] = self.terminal_resolution_adaptive

        if self.webrtc is not None:
            result['Webrtc'] = self.webrtc

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FrameRate') is not None:
            self.frame_rate = m.get('FrameRate')

        if m.get('SessionResolutionHeight') is not None:
            self.session_resolution_height = m.get('SessionResolutionHeight')

        if m.get('SessionResolutionWidth') is not None:
            self.session_resolution_width = m.get('SessionResolutionWidth')

        if m.get('StreamingMode') is not None:
            self.streaming_mode = m.get('StreamingMode')

        if m.get('TerminalResolutionAdaptive') is not None:
            self.terminal_resolution_adaptive = m.get('TerminalResolutionAdaptive')

        if m.get('Webrtc') is not None:
            self.webrtc = m.get('Webrtc')

        return self

class CreateAppInstanceGroupRequestUserInfo(DaraModel):
    def __init__(
        self,
        type: str = None,
    ):
        # The account type of the user.
        # 
        # Valid value:
        # 
        # *   Simple: convenience account
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class CreateAppInstanceGroupRequestUserDefinePolicy(DaraModel):
    def __init__(
        self,
        custom_config: str = None,
    ):
        # The content of the custom policy. The content must meet the specifications of image versions. To use this parameter, submit a ticket to apply to enable the whitelist feature.
        self.custom_config = custom_config

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.custom_config is not None:
            result['CustomConfig'] = self.custom_config

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomConfig') is not None:
            self.custom_config = m.get('CustomConfig')

        return self

class CreateAppInstanceGroupRequestStoragePolicy(DaraModel):
    def __init__(
        self,
        storage_type_list: List[str] = None,
        user_profile: main_models.CreateAppInstanceGroupRequestStoragePolicyUserProfile = None,
    ):
        # The storage types.
        self.storage_type_list = storage_type_list
        # User data roaming configuration.
        self.user_profile = user_profile

    def validate(self):
        if self.user_profile:
            self.user_profile.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.storage_type_list is not None:
            result['StorageTypeList'] = self.storage_type_list

        if self.user_profile is not None:
            result['UserProfile'] = self.user_profile.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('StorageTypeList') is not None:
            self.storage_type_list = m.get('StorageTypeList')

        if m.get('UserProfile') is not None:
            temp_model = main_models.CreateAppInstanceGroupRequestStoragePolicyUserProfile()
            self.user_profile = temp_model.from_map(m.get('UserProfile'))

        return self

class CreateAppInstanceGroupRequestStoragePolicyUserProfile(DaraModel):
    def __init__(
        self,
        remote_storage_path: str = None,
        remote_storage_type: str = None,
        user_profile_switch: bool = None,
    ):
        # Remote storage path for user data roaming.
        # 
        # - If left empty, the default value is the delivery group ID.
        # - For cross-delivery-group (within the same VPC) user data roaming, the same value must be configured for all participating delivery groups.
        self.remote_storage_path = remote_storage_path
        # Remote storage type used for user data roaming.
        self.remote_storage_type = remote_storage_type
        # User data roaming toggle.
        self.user_profile_switch = user_profile_switch

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.remote_storage_path is not None:
            result['RemoteStoragePath'] = self.remote_storage_path

        if self.remote_storage_type is not None:
            result['RemoteStorageType'] = self.remote_storage_type

        if self.user_profile_switch is not None:
            result['UserProfileSwitch'] = self.user_profile_switch

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RemoteStoragePath') is not None:
            self.remote_storage_path = m.get('RemoteStoragePath')

        if m.get('RemoteStorageType') is not None:
            self.remote_storage_type = m.get('RemoteStorageType')

        if m.get('UserProfileSwitch') is not None:
            self.user_profile_switch = m.get('UserProfileSwitch')

        return self

class CreateAppInstanceGroupRequestSecurityPolicy(DaraModel):
    def __init__(
        self,
        reset_after_unbind: bool = None,
        skip_user_auth_check: bool = None,
    ):
        # Specifies whether to reset after unbinding from a delivery group.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.reset_after_unbind = reset_after_unbind
        # Specifies whether to skip user permission verification.
        # 
        # Valid values:
        # 
        # *   true
        # *   false: This is the default value.
        self.skip_user_auth_check = skip_user_auth_check

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.reset_after_unbind is not None:
            result['ResetAfterUnbind'] = self.reset_after_unbind

        if self.skip_user_auth_check is not None:
            result['SkipUserAuthCheck'] = self.skip_user_auth_check

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResetAfterUnbind') is not None:
            self.reset_after_unbind = m.get('ResetAfterUnbind')

        if m.get('SkipUserAuthCheck') is not None:
            self.skip_user_auth_check = m.get('SkipUserAuthCheck')

        return self

class CreateAppInstanceGroupRequestRuntimePolicy(DaraModel):
    def __init__(
        self,
        debug_mode: str = None,
        per_session_per_app: bool = None,
        persistent_app_instance_schedule_mode: str = None,
        session_pre_open: str = None,
        session_type: str = None,
        session_user_generation_mode: str = None,
    ):
        # Specifies whether to enable the debugging mode. If you want to call the `GetDebugAppInstance` and `CreateImageFromAppInstanceGroup` operations, you must set this parameter to `ON`.
        # 
        # Valid values:
        # 
        # *   OFF
        # *   ON
        self.debug_mode = debug_mode
        # Only one application is allowed to be opened within a single session.
        # 
        # - When enabled, launching multiple applications from the delivery group will allocate a separate session for each application, resulting in higher session consumption.
        self.per_session_per_app = per_session_per_app
        # Persistent session scheduling mode.
        self.persistent_app_instance_schedule_mode = persistent_app_instance_schedule_mode
        # Session pre-launch toggle.
        # 
        # - If not specified, the default value is true.
        self.session_pre_open = session_pre_open
        # The session type.
        # 
        # Valid values:
        # 
        # *   CONSOLE: console session
        # *   NORMAL: Remote Desktop Protocol (RDP)-based O\\&M session
        self.session_type = session_type
        # The generation mode of the session users. Valid value:
        # - wyid. In this case, you must set sessionPreOpen to false.
        self.session_user_generation_mode = session_user_generation_mode

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.debug_mode is not None:
            result['DebugMode'] = self.debug_mode

        if self.per_session_per_app is not None:
            result['PerSessionPerApp'] = self.per_session_per_app

        if self.persistent_app_instance_schedule_mode is not None:
            result['PersistentAppInstanceScheduleMode'] = self.persistent_app_instance_schedule_mode

        if self.session_pre_open is not None:
            result['SessionPreOpen'] = self.session_pre_open

        if self.session_type is not None:
            result['SessionType'] = self.session_type

        if self.session_user_generation_mode is not None:
            result['SessionUserGenerationMode'] = self.session_user_generation_mode

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DebugMode') is not None:
            self.debug_mode = m.get('DebugMode')

        if m.get('PerSessionPerApp') is not None:
            self.per_session_per_app = m.get('PerSessionPerApp')

        if m.get('PersistentAppInstanceScheduleMode') is not None:
            self.persistent_app_instance_schedule_mode = m.get('PersistentAppInstanceScheduleMode')

        if m.get('SessionPreOpen') is not None:
            self.session_pre_open = m.get('SessionPreOpen')

        if m.get('SessionType') is not None:
            self.session_type = m.get('SessionType')

        if m.get('SessionUserGenerationMode') is not None:
            self.session_user_generation_mode = m.get('SessionUserGenerationMode')

        return self

class CreateAppInstanceGroupRequestNodePool(DaraModel):
    def __init__(
        self,
        max_idle_app_instance_amount: int = None,
        max_scaling_amount: int = None,
        node_amount: int = None,
        node_capacity: int = None,
        node_instance_type: str = None,
        recurrence_schedules: List[main_models.CreateAppInstanceGroupRequestNodePoolRecurrenceSchedules] = None,
        scaling_down_after_idle_minutes: int = None,
        scaling_step: int = None,
        scaling_usage_threshold: str = None,
        strategy_disable_date: str = None,
        strategy_enable_date: str = None,
        strategy_type: str = None,
        warm_up: bool = None,
    ):
        # Maximum number of idle sessions. When this value is specified, auto-scaling is triggered only if the session utilization exceeds `ScalingUsageThreshold` and the current number of idle sessions in the delivery group is less than `MaxIdleAppInstanceAmount`. Otherwise, it is considered that sufficient idle sessions are available, and no auto-scaling will occur. This parameter allows flexible control over elastic scaling behavior and helps reduce usage costs.
        self.max_idle_app_instance_amount = max_idle_app_instance_amount
        # The maximum number of resources that can be created for scale-out. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_USAGE`.
        self.max_scaling_amount = max_scaling_amount
        # The number of resources that you want to purchase. Valid values: 1 to 100.
        # 
        # > 
        # 
        # *   This parameter is required if the resources are subscription resources.
        # 
        # *   If the resources are pay-as-you-go resources, this parameter is required only if you set `StrategyType` to `NODE_FIXED` or `NODE_SCALING_BY_USAGE`.
        self.node_amount = node_amount
        # The maximum number of sessions to which a resource can connect at the same time. If a resource connects to a large number of sessions at the same time, the user experience can be compromised. The value range varies based on the resource type. The following items describe the value ranges of different resource types:
        # 
        # *   appstreaming.general.4c8g: 1 to 2
        # *   appstreaming.general.8c16g: 1 to 4
        # *   appstreaming.vgpu.8c16g.4g: 1 to 4
        # *   appstreaming.vgpu.8c31g.16g: 1 to 4
        # *   appstreaming.vgpu.14c93g.12g: 1 to 6
        self.node_capacity = node_capacity
        # The ID of the resource type that you want to purchase. You can call the [ListNodeInstanceType](https://help.aliyun.com/document_detail/428502.html) operation to obtain the ID.
        # 
        # Valid values:
        # 
        # *   appstreaming.vgpu.8c16g.4g: WUYING - Graphics_8 vCPUs, 16 GiB Memory, 4 GiB GPU Memory
        # *   appstreaming.general.8c16g: WUYING - General_8 vCPUs, 16 GiB Memory
        # *   appstreaming.general.4c8g: WUYING - General_4 vCPUs, 8 GiB Memory
        # *   appstreaming.vgpu.14c93g.12g: WUYING - Graphics_14 vCPUs, 93 GiB Memory, 12 GiB GPU Memory.
        # *   appstreaming.vgpu.8c31g.16g: WUYING - Graphics_8 vCPUs, 31 GiB Memory, 16 GiB GPU Memory
        self.node_instance_type = node_instance_type
        # The schedules of the scaling policy. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_SCHEDULE`.
        self.recurrence_schedules = recurrence_schedules
        # The maximum retention period of a resource to which no session is connected. If no session is connected to a resource, the resource is automatically scaled in after the specified retention period elapses. Valid values: 5 to 120. Default value: 5. Unit: minutes. If one of the following situations occurs, the resource is not scaled in.
        # 
        # *   If automatic scale-out is triggered after the resource is scaled in, the scale-in is not executed. This prevents repeated scale-in and scale-out.
        # *   If automatic scale-out is triggered due to an increase in the number of sessions during the specified period of time, the resource is not scaled in and the countdown restarts.
        self.scaling_down_after_idle_minutes = scaling_down_after_idle_minutes
        # The number of resources that are created each time resources are scaled out. Valid values: 1 to 10. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_USAGE`.
        self.scaling_step = scaling_step
        # The upper limit of session usage. If the session usage exceeds the specified upper limit, auto scaling is automatically triggered. The session usage is calculated by using the following formula: `Session usage = Number of current sessions/(Total number of resources × Number of concurrent sessions) × 100%`. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_USAGE`. Valid values: 0 to 100. Default value: 85.
        self.scaling_usage_threshold = scaling_usage_threshold
        # The expiration date of the scaling policy. Format: yyyy-MM-dd. The interval between the expiration date and the effective date must be from 7 days to 1 year. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_SCHEDULE`.
        self.strategy_disable_date = strategy_disable_date
        # The effective date of the scaling policy. Format: yyyy-MM-dd. The date must be the same as or later than the current date. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_SCHEDULE`.
        self.strategy_enable_date = strategy_enable_date
        # The scaling policy of resources.
        # 
        # > 
        # 
        # *   `NODE_FIXED`: fixed number of resources. This value is applicable to pay-as-you-go resources and subscription resources.
        # 
        # *   `NODE_SCALING_BY_USAGE`: auto scaling. This value is applicable to pay-as-you-go resources and subscription resources.
        # 
        # *   `NODE_SCALING_BY_SCHEDULE`: scheduled scaling. This value is applicable only to pay-as-you-go resources.
        # 
        # Valid values:
        # 
        # *   NODE_FIXED: fixed number of resources
        # *   NODE_SCALING_BY_SCHEDULE: scheduled scaling
        # *   NODE_SCALING_BY_USAGE: auto scaling
        self.strategy_type = strategy_type
        # Specifies whether to enable the warmup policy for resources. This parameter is required if you set `StrategyType` to `NODE_SCALING_BY_SCHEDULE`.
        self.warm_up = warm_up

    def validate(self):
        if self.recurrence_schedules:
            for v1 in self.recurrence_schedules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_idle_app_instance_amount is not None:
            result['MaxIdleAppInstanceAmount'] = self.max_idle_app_instance_amount

        if self.max_scaling_amount is not None:
            result['MaxScalingAmount'] = self.max_scaling_amount

        if self.node_amount is not None:
            result['NodeAmount'] = self.node_amount

        if self.node_capacity is not None:
            result['NodeCapacity'] = self.node_capacity

        if self.node_instance_type is not None:
            result['NodeInstanceType'] = self.node_instance_type

        result['RecurrenceSchedules'] = []
        if self.recurrence_schedules is not None:
            for k1 in self.recurrence_schedules:
                result['RecurrenceSchedules'].append(k1.to_map() if k1 else None)

        if self.scaling_down_after_idle_minutes is not None:
            result['ScalingDownAfterIdleMinutes'] = self.scaling_down_after_idle_minutes

        if self.scaling_step is not None:
            result['ScalingStep'] = self.scaling_step

        if self.scaling_usage_threshold is not None:
            result['ScalingUsageThreshold'] = self.scaling_usage_threshold

        if self.strategy_disable_date is not None:
            result['StrategyDisableDate'] = self.strategy_disable_date

        if self.strategy_enable_date is not None:
            result['StrategyEnableDate'] = self.strategy_enable_date

        if self.strategy_type is not None:
            result['StrategyType'] = self.strategy_type

        if self.warm_up is not None:
            result['WarmUp'] = self.warm_up

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('MaxIdleAppInstanceAmount') is not None:
            self.max_idle_app_instance_amount = m.get('MaxIdleAppInstanceAmount')

        if m.get('MaxScalingAmount') is not None:
            self.max_scaling_amount = m.get('MaxScalingAmount')

        if m.get('NodeAmount') is not None:
            self.node_amount = m.get('NodeAmount')

        if m.get('NodeCapacity') is not None:
            self.node_capacity = m.get('NodeCapacity')

        if m.get('NodeInstanceType') is not None:
            self.node_instance_type = m.get('NodeInstanceType')

        self.recurrence_schedules = []
        if m.get('RecurrenceSchedules') is not None:
            for k1 in m.get('RecurrenceSchedules'):
                temp_model = main_models.CreateAppInstanceGroupRequestNodePoolRecurrenceSchedules()
                self.recurrence_schedules.append(temp_model.from_map(k1))

        if m.get('ScalingDownAfterIdleMinutes') is not None:
            self.scaling_down_after_idle_minutes = m.get('ScalingDownAfterIdleMinutes')

        if m.get('ScalingStep') is not None:
            self.scaling_step = m.get('ScalingStep')

        if m.get('ScalingUsageThreshold') is not None:
            self.scaling_usage_threshold = m.get('ScalingUsageThreshold')

        if m.get('StrategyDisableDate') is not None:
            self.strategy_disable_date = m.get('StrategyDisableDate')

        if m.get('StrategyEnableDate') is not None:
            self.strategy_enable_date = m.get('StrategyEnableDate')

        if m.get('StrategyType') is not None:
            self.strategy_type = m.get('StrategyType')

        if m.get('WarmUp') is not None:
            self.warm_up = m.get('WarmUp')

        return self

class CreateAppInstanceGroupRequestNodePoolRecurrenceSchedules(DaraModel):
    def __init__(
        self,
        recurrence_type: str = None,
        recurrence_values: List[int] = None,
        timer_periods: List[main_models.CreateAppInstanceGroupRequestNodePoolRecurrenceSchedulesTimerPeriods] = None,
    ):
        # The schedule type of the scaling policy. This parameter must be configured together with `RecurrenceValues`.``
        # 
        # Valid value:
        # 
        # *   Weekly: The scaling policy is executed on specific days each week.
        self.recurrence_type = recurrence_type
        # The days of each week on which the scaling policy is executed.
        self.recurrence_values = recurrence_values
        # The time periods during which the scaling policy can be executed. The time periods must meet the following requirements:
        # 
        # *   Up to three time periods can be added.
        # *   Time periods cannot be overlapped.
        # *   The interval between two consecutive time periods must be greater than or equal to 5 minutes.
        # *   Each time period must be greater than or equal to 15 minutes.
        # *   The total length of the time periods that you specify cannot be greater than a day.
        self.timer_periods = timer_periods

    def validate(self):
        if self.timer_periods:
            for v1 in self.timer_periods:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.recurrence_type is not None:
            result['RecurrenceType'] = self.recurrence_type

        if self.recurrence_values is not None:
            result['RecurrenceValues'] = self.recurrence_values

        result['TimerPeriods'] = []
        if self.timer_periods is not None:
            for k1 in self.timer_periods:
                result['TimerPeriods'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RecurrenceType') is not None:
            self.recurrence_type = m.get('RecurrenceType')

        if m.get('RecurrenceValues') is not None:
            self.recurrence_values = m.get('RecurrenceValues')

        self.timer_periods = []
        if m.get('TimerPeriods') is not None:
            for k1 in m.get('TimerPeriods'):
                temp_model = main_models.CreateAppInstanceGroupRequestNodePoolRecurrenceSchedulesTimerPeriods()
                self.timer_periods.append(temp_model.from_map(k1))

        return self

class CreateAppInstanceGroupRequestNodePoolRecurrenceSchedulesTimerPeriods(DaraModel):
    def __init__(
        self,
        amount: int = None,
        end_time: str = None,
        start_time: str = None,
    ):
        # The number of resources.
        self.amount = amount
        # The end time of the time period. Format: HH:mm.
        self.end_time = end_time
        # The start time of the time period. Format: HH:mm.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.amount is not None:
            result['Amount'] = self.amount

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Amount') is not None:
            self.amount = m.get('Amount')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self

class CreateAppInstanceGroupRequestNetwork(DaraModel):
    def __init__(
        self,
        domain_rules: List[main_models.CreateAppInstanceGroupRequestNetworkDomainRules] = None,
        ip_expire_minutes: int = None,
        office_site_id: str = None,
        routes: List[main_models.CreateAppInstanceGroupRequestNetworkRoutes] = None,
        strategy_type: str = None,
        v_switch_ids: List[str] = None,
    ):
        # The domain name rules.
        self.domain_rules = domain_rules
        # The validity period of the public IP address. If the specified value is exceeded, the IP address is updated at next logon. Minimum value: 60. Unit: minutes.
        self.ip_expire_minutes = ip_expire_minutes
        # Office Network ID.
        self.office_site_id = office_site_id
        # The route settings. This parameter is available only if you set `StrategyType` to `Mixed`.
        self.routes = routes
        # The type of the network policy.
        # 
        # Valid values:
        # 
        # *   Mixed: the hybrid mode. In this mode, a device is deployed in one virtual private cloud (VPC). Two NICs are provided and an independent public IP address is configured for the device.
        # *   Shared: the shared mode. In this mode, a single NIC is provided for a device and the network is accessed by using NAT Gateway.
        self.strategy_type = strategy_type
        # List of virtual switch IDs.
        # - Valid only for custom office networks.
        self.v_switch_ids = v_switch_ids

    def validate(self):
        if self.domain_rules:
            for v1 in self.domain_rules:
                 if v1:
                    v1.validate()
        if self.routes:
            for v1 in self.routes:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['DomainRules'] = []
        if self.domain_rules is not None:
            for k1 in self.domain_rules:
                result['DomainRules'].append(k1.to_map() if k1 else None)

        if self.ip_expire_minutes is not None:
            result['IpExpireMinutes'] = self.ip_expire_minutes

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        result['Routes'] = []
        if self.routes is not None:
            for k1 in self.routes:
                result['Routes'].append(k1.to_map() if k1 else None)

        if self.strategy_type is not None:
            result['StrategyType'] = self.strategy_type

        if self.v_switch_ids is not None:
            result['VSwitchIds'] = self.v_switch_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.domain_rules = []
        if m.get('DomainRules') is not None:
            for k1 in m.get('DomainRules'):
                temp_model = main_models.CreateAppInstanceGroupRequestNetworkDomainRules()
                self.domain_rules.append(temp_model.from_map(k1))

        if m.get('IpExpireMinutes') is not None:
            self.ip_expire_minutes = m.get('IpExpireMinutes')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        self.routes = []
        if m.get('Routes') is not None:
            for k1 in m.get('Routes'):
                temp_model = main_models.CreateAppInstanceGroupRequestNetworkRoutes()
                self.routes.append(temp_model.from_map(k1))

        if m.get('StrategyType') is not None:
            self.strategy_type = m.get('StrategyType')

        if m.get('VSwitchIds') is not None:
            self.v_switch_ids = m.get('VSwitchIds')

        return self

class CreateAppInstanceGroupRequestNetworkRoutes(DaraModel):
    def __init__(
        self,
        destination: str = None,
        mode: str = None,
    ):
        # The destination. The value is a CIDR block.
        self.destination = destination
        # The network egress mode.
        # 
        # Valid value:
        # 
        # *   Shared: accesses the network by using NAT Gateway.
        self.mode = mode

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.destination is not None:
            result['Destination'] = self.destination

        if self.mode is not None:
            result['Mode'] = self.mode

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Destination') is not None:
            self.destination = m.get('Destination')

        if m.get('Mode') is not None:
            self.mode = m.get('Mode')

        return self

class CreateAppInstanceGroupRequestNetworkDomainRules(DaraModel):
    def __init__(
        self,
        domain: str = None,
        policy: str = None,
    ):
        # The domain name.
        self.domain = domain
        # The policy used for the domain name.
        # 
        # Valid values:
        # 
        # *   allow
        # *   block
        self.policy = policy

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.domain is not None:
            result['Domain'] = self.domain

        if self.policy is not None:
            result['Policy'] = self.policy

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('Policy') is not None:
            self.policy = m.get('Policy')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListAuthorizedUserGroupsResponseBody(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        request_id: str = None,
        total_count: int = None,
        user_groups: List[main_models.ListAuthorizedUserGroupsResponseBodyUserGroups] = None,
    ):
        # The page number.
        self.page_number = page_number
        # The maximum number of entries returned on each page.
        self.page_size = page_size
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count
        # The information about the user groups.
        self.user_groups = user_groups

    def validate(self):
        if self.user_groups:
            for v1 in self.user_groups:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        result['UserGroups'] = []
        if self.user_groups is not None:
            for k1 in self.user_groups:
                result['UserGroups'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        self.user_groups = []
        if m.get('UserGroups') is not None:
            for k1 in m.get('UserGroups'):
                temp_model = main_models.ListAuthorizedUserGroupsResponseBodyUserGroups()
                self.user_groups.append(temp_model.from_map(k1))

        return self

class ListAuthorizedUserGroupsResponseBodyUserGroups(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        auth_mode: str = None,
        group_id: str = None,
        group_name: str = None,
    ):
        # The ID of the delivery group.
        self.app_instance_group_id = app_instance_group_id
        # The authorization mode.
        # 
        # Valid values:
        # 
        # *   App: authorizes access to apps.
        # *   AppInstanceGroup: authorizes access to delivery groups.
        # *   Session: authorizes access to sessions.
        self.auth_mode = auth_mode
        # The ID of the user group.
        self.group_id = group_id
        # The name of the user group.
        self.group_name = group_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.auth_mode is not None:
            result['AuthMode'] = self.auth_mode

        if self.group_id is not None:
            result['GroupId'] = self.group_id

        if self.group_name is not None:
            result['GroupName'] = self.group_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AuthMode') is not None:
            self.auth_mode = m.get('AuthMode')

        if m.get('GroupId') is not None:
            self.group_id = m.get('GroupId')

        if m.get('GroupName') is not None:
            self.group_name = m.get('GroupName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class GetConnectionTicketRequest(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        app_id: str = None,
        app_instance_group_id_list: List[str] = None,
        app_instance_id: str = None,
        app_instance_persistent_id: str = None,
        app_policy_id: str = None,
        app_start_param: str = None,
        app_version: str = None,
        biz_region_id: str = None,
        end_user_id: str = None,
        environment_config: str = None,
        product_type: str = None,
        task_id: str = None,
    ):
        self.access_type = access_type
        # The application ID.
        # 
        # >  This parameter is required for the first call to this operation and optional for subsequent calls to the operation.
        self.app_id = app_id
        # The delivery groups.
        # 
        # > *   If you configure this parameter, the system assigns application instances only among the specified authorized delivery groups. 
        # > *   This parameter is required if you configure `AppInstanceId` or `AppInstancePersistentId`.
        self.app_instance_group_id_list = app_instance_group_id_list
        # The ID of the application instance.
        # 
        # > *   If you configure this parameter, the system attempts to assign only the specified application instance.
        # > *   If you configure this parameter, you must also configure `AppInstanceGroupIdList` and the number of delivery groups specified by `AppInstanceGroupIdList` must be 1.
        self.app_instance_id = app_instance_id
        # The ID of the persistent session.
        self.app_instance_persistent_id = app_instance_persistent_id
        self.app_policy_id = app_policy_id
        # The parameters that are configured to start the application. For information about how to obtain these parameters, see [Obtain parameters configured to install and start an application](https://help.aliyun.com/document_detail/426045.html).
        self.app_start_param = app_start_param
        # The application version. If you configure this parameter, only an application of the specified version is started. If you do not configure this parameter, an application of a random authorized version is started.
        self.app_version = app_version
        # The region ID.
        # 
        # >  If you configure this parameter, the system assigns application instances only among the delivery groups that reside in the specified region.
        self.biz_region_id = biz_region_id
        # The ID of the convenience account.
        # 
        # This parameter is required.
        self.end_user_id = end_user_id
        # The environment configuration.
        self.environment_config = environment_config
        # The product type.
        # 
        # Valid values:
        # 
        # *   CloudApp: App Streaming
        # *   AndroidCloud: Cloud Phone
        # 
        # This parameter is required.
        self.product_type = product_type
        # The task ID.
        # 
        # >  This parameter is required for calls other than the first call to this operation. You can use this parameter to query the task status and connection credential.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.app_id is not None:
            result['AppId'] = self.app_id

        if self.app_instance_group_id_list is not None:
            result['AppInstanceGroupIdList'] = self.app_instance_group_id_list

        if self.app_instance_id is not None:
            result['AppInstanceId'] = self.app_instance_id

        if self.app_instance_persistent_id is not None:
            result['AppInstancePersistentId'] = self.app_instance_persistent_id

        if self.app_policy_id is not None:
            result['AppPolicyId'] = self.app_policy_id

        if self.app_start_param is not None:
            result['AppStartParam'] = self.app_start_param

        if self.app_version is not None:
            result['AppVersion'] = self.app_version

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.end_user_id is not None:
            result['EndUserId'] = self.end_user_id

        if self.environment_config is not None:
            result['EnvironmentConfig'] = self.environment_config

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('AppId') is not None:
            self.app_id = m.get('AppId')

        if m.get('AppInstanceGroupIdList') is not None:
            self.app_instance_group_id_list = m.get('AppInstanceGroupIdList')

        if m.get('AppInstanceId') is not None:
            self.app_instance_id = m.get('AppInstanceId')

        if m.get('AppInstancePersistentId') is not None:
            self.app_instance_persistent_id = m.get('AppInstancePersistentId')

        if m.get('AppPolicyId') is not None:
            self.app_policy_id = m.get('AppPolicyId')

        if m.get('AppStartParam') is not None:
            self.app_start_param = m.get('AppStartParam')

        if m.get('AppVersion') is not None:
            self.app_version = m.get('AppVersion')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('EndUserId') is not None:
            self.end_user_id = m.get('EndUserId')

        if m.get('EnvironmentConfig') is not None:
            self.environment_config = m.get('EnvironmentConfig')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListAppInstancesRequest(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        app_instance_id: str = None,
        app_instance_id_list: List[str] = None,
        include_deleted: bool = None,
        page_number: int = None,
        page_size: int = None,
        status: List[str] = None,
        user_id_list: List[str] = None,
    ):
        # The ID of the delivery group.
        # 
        # This parameter is required.
        self.app_instance_group_id = app_instance_group_id
        # The ID of the application instance.
        self.app_instance_id = app_instance_id
        # The IDs of the application instances. Up to 100 IDs can be specified.
        self.app_instance_id_list = app_instance_id_list
        # Specifies whether to query the information about deleted app instances. If you set this parameter to true, you must configure AppInstanceIdList. Otherwise, a parameter error is reported.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.include_deleted = include_deleted
        # The page number. Default value: `1`. We recommend that you specify this parameter.
        self.page_number = page_number
        # The number of entries per page. The value cannot be greater than `100`. Default value: `20`. We recommend that you specify this parameter.
        self.page_size = page_size
        # The status of the application instances.
        self.status = status
        # The user IDs. You can specify up to 100 IDs.
        self.user_id_list = user_id_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.app_instance_id is not None:
            result['AppInstanceId'] = self.app_instance_id

        if self.app_instance_id_list is not None:
            result['AppInstanceIdList'] = self.app_instance_id_list

        if self.include_deleted is not None:
            result['IncludeDeleted'] = self.include_deleted

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.status is not None:
            result['Status'] = self.status

        if self.user_id_list is not None:
            result['UserIdList'] = self.user_id_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AppInstanceId') is not None:
            self.app_instance_id = m.get('AppInstanceId')

        if m.get('AppInstanceIdList') is not None:
            self.app_instance_id_list = m.get('AppInstanceIdList')

        if m.get('IncludeDeleted') is not None:
            self.include_deleted = m.get('IncludeDeleted')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('UserIdList') is not None:
            self.user_id_list = m.get('UserIdList')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class GetAppInstanceGroupResponseBody(DaraModel):
    def __init__(
        self,
        app_instance_group_models: main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModels = None,
        request_id: str = None,
    ):
        # AppInstanceGroupModels
        self.app_instance_group_models = app_instance_group_models
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.app_instance_group_models:
            self.app_instance_group_models.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_models is not None:
            result['AppInstanceGroupModels'] = self.app_instance_group_models.to_map()

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupModels') is not None:
            temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModels()
            self.app_instance_group_models = temp_model.from_map(m.get('AppInstanceGroupModels'))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModels(DaraModel):
    def __init__(
        self,
        access_type: str = None,
        amount: int = None,
        app_center_image_id: str = None,
        app_center_image_name: str = None,
        app_instance_group_id: str = None,
        app_instance_group_name: str = None,
        app_instance_type: str = None,
        app_instance_type_name: str = None,
        app_policy_id: str = None,
        apps: List[main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsApps] = None,
        auth_mode: str = None,
        charge_resource_mode: str = None,
        charge_type: str = None,
        expired_time: str = None,
        gmt_create: str = None,
        max_amount: int = None,
        min_amount: int = None,
        node_pool: List[main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool] = None,
        office_site_id: str = None,
        os_type: str = None,
        ota_info: main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo = None,
        product_type: str = None,
        region_id: str = None,
        reserve_amount_ratio: str = None,
        reserve_max_amount: int = None,
        reserve_min_amount: int = None,
        resource_status: str = None,
        scaling_down_after_idle_minutes: int = None,
        scaling_step: int = None,
        scaling_usage_threshold: str = None,
        session_timeout: str = None,
        session_type: str = None,
        skip_user_auth_check: bool = None,
        spec_id: str = None,
        status: str = None,
        support_user_group_mixed_auth: bool = None,
        tags: List[main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsTags] = None,
        user_group_auth_mode: str = None,
    ):
        # 接入类型。
        self.access_type = access_type
        # The number of subscription resources. Minimum value: 1.
        self.amount = amount
        # The image ID of the application.
        self.app_center_image_id = app_center_image_id
        # The image name of the application.
        self.app_center_image_name = app_center_image_name
        # The ID of the delivery group.
        self.app_instance_group_id = app_instance_group_id
        # The name of the delivery group.
        self.app_instance_group_name = app_instance_group_name
        # The resource type of the delivery group.
        self.app_instance_type = app_instance_type
        # The name of the resource type of the delivery group.
        self.app_instance_type_name = app_instance_type_name
        # The policy ID of the application.
        self.app_policy_id = app_policy_id
        # The applications.
        self.apps = apps
        # 授权模式。
        self.auth_mode = auth_mode
        # The sales mode.
        # 
        # Valid values:
        # 
        # *   AppInstance: by session
        # *   Node: by resource
        self.charge_resource_mode = charge_resource_mode
        # The billing method.
        # 
        # Valid values:
        # 
        # *   PostPaid: pay-as-you-go
        # *   PrePaid: subscription
        self.charge_type = charge_type
        # The time when the delivery group expires.
        self.expired_time = expired_time
        # The time when the delivery group was created.
        self.gmt_create = gmt_create
        # The maximum number of instances. Minimum value: 1.
        self.max_amount = max_amount
        # The minimum number of instances. Minimum value: 1.
        self.min_amount = min_amount
        # The information about the resource group.
        self.node_pool = node_pool
        # 办公网络ID。
        self.office_site_id = office_site_id
        # The type of the operating system.
        self.os_type = os_type
        # The information about the over-the-air (OTA) update task.
        self.ota_info = ota_info
        # The product type.
        self.product_type = product_type
        # The ID of the region where the delivery group resides. For information about the supported regions, see [Limits](https://help.aliyun.com/document_detail/426036.html).
        self.region_id = region_id
        # The percentage of reserved instances. The value indicates the percentage of unused sessions in the delivery group. Valid values: 0 to 99.
        self.reserve_amount_ratio = reserve_amount_ratio
        # The maximum number of reserved instances. The value indicates the maximum number of unused sessions in the delivery group. Minimum value: 1.
        self.reserve_max_amount = reserve_max_amount
        # The minimum number of reserved instances. The value indicates the minimum number of unused sessions in the delivery group. Minimum value: 1.
        self.reserve_min_amount = reserve_min_amount
        # The resource status.
        self.resource_status = resource_status
        # The duration for which no session is connected. Unit: minutes. If no session is connected in the resources after the specified duration elapses, automatic scale-in is triggered. Minimum value: 0.
        self.scaling_down_after_idle_minutes = scaling_down_after_idle_minutes
        # The number of sessions that are created each time the delivery group is scaled out. Minimum value: 1.
        self.scaling_step = scaling_step
        # The upper limit of session usage. If the session usage exceeds the specified upper limit, auto scaling is automatically triggered. The session usage rate is calculated by using the following formula: Session usage rate = Number of sessions in use/Total number of sessions × 100%. Valid values: 0 to 99.
        self.scaling_usage_threshold = scaling_usage_threshold
        # The duration for which sessions are retained after disconnection. Unit: minutes. After an end user disconnects from a session, the session is closed only after the specified duration elapses. If you want to permanently retain sessions, set this parameter to `-1`. Valid values:-1 and 3 to 300. Default value: `15`.
        self.session_timeout = session_timeout
        # 会话类型。
        self.session_type = session_type
        # Indicates whether user permission verification is skipped.
        # 
        # Valid values:
        # 
        # *   true
        # *   false: This is the default value.
        self.skip_user_auth_check = skip_user_auth_check
        # The specification ID that uniquely corresponds to the ID of the delivery group.
        self.spec_id = spec_id
        # The status of the delivery group.
        # 
        # Valid values:
        # 
        # *   PUBLISHED: The delivery group is published.
        # *   FAILED: The delivery group failed to be published.
        # *   MAINTAIN_FAILED: The delivery group failed to be updated.
        # *   EXPIRED: The delivery group is expired.
        # *   MAINTAINING: The delivery group is being updated.
        # *   CEASED: The delivery group has overdue payments.
        # *   EXPIRED_RECYCLING: The delivery group is expired and being recycled.
        # *   DEPLOYING: The delivery group is being published.
        self.status = status
        self.support_user_group_mixed_auth = support_user_group_mixed_auth
        # 资源标签列表。
        self.tags = tags
        self.user_group_auth_mode = user_group_auth_mode

    def validate(self):
        if self.apps:
            for v1 in self.apps:
                 if v1:
                    v1.validate()
        if self.node_pool:
            for v1 in self.node_pool:
                 if v1:
                    v1.validate()
        if self.ota_info:
            self.ota_info.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_type is not None:
            result['AccessType'] = self.access_type

        if self.amount is not None:
            result['Amount'] = self.amount

        if self.app_center_image_id is not None:
            result['AppCenterImageId'] = self.app_center_image_id

        if self.app_center_image_name is not None:
            result['AppCenterImageName'] = self.app_center_image_name

        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.app_instance_group_name is not None:
            result['AppInstanceGroupName'] = self.app_instance_group_name

        if self.app_instance_type is not None:
            result['AppInstanceType'] = self.app_instance_type

        if self.app_instance_type_name is not None:
            result['AppInstanceTypeName'] = self.app_instance_type_name

        if self.app_policy_id is not None:
            result['AppPolicyId'] = self.app_policy_id

        result['Apps'] = []
        if self.apps is not None:
            for k1 in self.apps:
                result['Apps'].append(k1.to_map() if k1 else None)

        if self.auth_mode is not None:
            result['AuthMode'] = self.auth_mode

        if self.charge_resource_mode is not None:
            result['ChargeResourceMode'] = self.charge_resource_mode

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        if self.expired_time is not None:
            result['ExpiredTime'] = self.expired_time

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        if self.max_amount is not None:
            result['MaxAmount'] = self.max_amount

        if self.min_amount is not None:
            result['MinAmount'] = self.min_amount

        result['NodePool'] = []
        if self.node_pool is not None:
            for k1 in self.node_pool:
                result['NodePool'].append(k1.to_map() if k1 else None)

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.os_type is not None:
            result['OsType'] = self.os_type

        if self.ota_info is not None:
            result['OtaInfo'] = self.ota_info.to_map()

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.reserve_amount_ratio is not None:
            result['ReserveAmountRatio'] = self.reserve_amount_ratio

        if self.reserve_max_amount is not None:
            result['ReserveMaxAmount'] = self.reserve_max_amount

        if self.reserve_min_amount is not None:
            result['ReserveMinAmount'] = self.reserve_min_amount

        if self.resource_status is not None:
            result['ResourceStatus'] = self.resource_status

        if self.scaling_down_after_idle_minutes is not None:
            result['ScalingDownAfterIdleMinutes'] = self.scaling_down_after_idle_minutes

        if self.scaling_step is not None:
            result['ScalingStep'] = self.scaling_step

        if self.scaling_usage_threshold is not None:
            result['ScalingUsageThreshold'] = self.scaling_usage_threshold

        if self.session_timeout is not None:
            result['SessionTimeout'] = self.session_timeout

        if self.session_type is not None:
            result['SessionType'] = self.session_type

        if self.skip_user_auth_check is not None:
            result['SkipUserAuthCheck'] = self.skip_user_auth_check

        if self.spec_id is not None:
            result['SpecId'] = self.spec_id

        if self.status is not None:
            result['Status'] = self.status

        if self.support_user_group_mixed_auth is not None:
            result['SupportUserGroupMixedAuth'] = self.support_user_group_mixed_auth

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.user_group_auth_mode is not None:
            result['UserGroupAuthMode'] = self.user_group_auth_mode

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessType') is not None:
            self.access_type = m.get('AccessType')

        if m.get('Amount') is not None:
            self.amount = m.get('Amount')

        if m.get('AppCenterImageId') is not None:
            self.app_center_image_id = m.get('AppCenterImageId')

        if m.get('AppCenterImageName') is not None:
            self.app_center_image_name = m.get('AppCenterImageName')

        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AppInstanceGroupName') is not None:
            self.app_instance_group_name = m.get('AppInstanceGroupName')

        if m.get('AppInstanceType') is not None:
            self.app_instance_type = m.get('AppInstanceType')

        if m.get('AppInstanceTypeName') is not None:
            self.app_instance_type_name = m.get('AppInstanceTypeName')

        if m.get('AppPolicyId') is not None:
            self.app_policy_id = m.get('AppPolicyId')

        self.apps = []
        if m.get('Apps') is not None:
            for k1 in m.get('Apps'):
                temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsApps()
                self.apps.append(temp_model.from_map(k1))

        if m.get('AuthMode') is not None:
            self.auth_mode = m.get('AuthMode')

        if m.get('ChargeResourceMode') is not None:
            self.charge_resource_mode = m.get('ChargeResourceMode')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        if m.get('ExpiredTime') is not None:
            self.expired_time = m.get('ExpiredTime')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        if m.get('MaxAmount') is not None:
            self.max_amount = m.get('MaxAmount')

        if m.get('MinAmount') is not None:
            self.min_amount = m.get('MinAmount')

        self.node_pool = []
        if m.get('NodePool') is not None:
            for k1 in m.get('NodePool'):
                temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool()
                self.node_pool.append(temp_model.from_map(k1))

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('OsType') is not None:
            self.os_type = m.get('OsType')

        if m.get('OtaInfo') is not None:
            temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo()
            self.ota_info = temp_model.from_map(m.get('OtaInfo'))

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ReserveAmountRatio') is not None:
            self.reserve_amount_ratio = m.get('ReserveAmountRatio')

        if m.get('ReserveMaxAmount') is not None:
            self.reserve_max_amount = m.get('ReserveMaxAmount')

        if m.get('ReserveMinAmount') is not None:
            self.reserve_min_amount = m.get('ReserveMinAmount')

        if m.get('ResourceStatus') is not None:
            self.resource_status = m.get('ResourceStatus')

        if m.get('ScalingDownAfterIdleMinutes') is not None:
            self.scaling_down_after_idle_minutes = m.get('ScalingDownAfterIdleMinutes')

        if m.get('ScalingStep') is not None:
            self.scaling_step = m.get('ScalingStep')

        if m.get('ScalingUsageThreshold') is not None:
            self.scaling_usage_threshold = m.get('ScalingUsageThreshold')

        if m.get('SessionTimeout') is not None:
            self.session_timeout = m.get('SessionTimeout')

        if m.get('SessionType') is not None:
            self.session_type = m.get('SessionType')

        if m.get('SkipUserAuthCheck') is not None:
            self.skip_user_auth_check = m.get('SkipUserAuthCheck')

        if m.get('SpecId') is not None:
            self.spec_id = m.get('SpecId')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('SupportUserGroupMixedAuth') is not None:
            self.support_user_group_mixed_auth = m.get('SupportUserGroupMixedAuth')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('UserGroupAuthMode') is not None:
            self.user_group_auth_mode = m.get('UserGroupAuthMode')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        scope: str = None,
        value: str = None,
    ):
        # 标签键。
        self.key = key
        # 标签类型。
        self.scope = scope
        # 标签值。
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.scope is not None:
            result['Scope'] = self.scope

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Scope') is not None:
            self.scope = m.get('Scope')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsOtaInfo(DaraModel):
    def __init__(
        self,
        new_ota_version: str = None,
        ota_version: str = None,
        task_id: str = None,
    ):
        # The new OTA version. A null value indicates that no new version is available.
        self.new_ota_version = new_ota_version
        # The current OTA version.
        self.ota_version = ota_version
        # The ID of the OTA update task.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.new_ota_version is not None:
            result['NewOtaVersion'] = self.new_ota_version

        if self.ota_version is not None:
            result['OtaVersion'] = self.ota_version

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NewOtaVersion') is not None:
            self.new_ota_version = m.get('NewOtaVersion')

        if m.get('OtaVersion') is not None:
            self.ota_version = m.get('OtaVersion')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePool(DaraModel):
    def __init__(
        self,
        amount: int = None,
        max_idle_app_instance_amount: int = None,
        max_scaling_amount: int = None,
        node_amount: int = None,
        node_capacity: int = None,
        node_instance_type: str = None,
        node_pool_id: str = None,
        node_type_name: str = None,
        node_used: int = None,
        recurrence_schedules: List[main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules] = None,
        scaling_down_after_idle_minutes: int = None,
        scaling_node_amount: int = None,
        scaling_node_used: int = None,
        scaling_step: int = None,
        scaling_usage_threshold: str = None,
        strategy_disable_date: str = None,
        strategy_enable_date: str = None,
        strategy_type: str = None,
        warm_up: bool = None,
    ):
        # The number of resources purchased when the delivery group was created.
        self.amount = amount
        # 空闲会话数上限。指定该值时，当会话使用率超过`ScalingUsageThreshold`且当前交付组空闲会话数小于`MaxIdleAppInstanceAmount`时，才会触发自动扩容，否则认为交付组空闲会话已足够使用，不自动扩容。该参数可用于灵活控制弹性扩容行为和降低使用成本。
        self.max_idle_app_instance_amount = max_idle_app_instance_amount
        # The maximum number of resources that can be created for scale-out.
        self.max_scaling_amount = max_scaling_amount
        # The total number of subscription resources.
        self.node_amount = node_amount
        # The maximum number of sessions to which a resource can connect at the same time. If a resource connects to a large number of sessions at the same time, user experience can be compromised. The value range varies based on the resource type. The following items describe the value ranges of different resource types:
        # 
        # *   appstreaming.general.4c8g: 1 to 2
        # *   appstreaming.general.8c16g: 1 to 4
        # *   appstreaming.vgpu.8c16g.4g: 1 to 4
        # *   appstreaming.vgpu.8c31g.16g: 1 to 4
        # *   appstreaming.vgpu.14c93g.12g: 1 to 6
        self.node_capacity = node_capacity
        # The ID of the resource type that you purchase.
        self.node_instance_type = node_instance_type
        # The ID of the resource group.
        self.node_pool_id = node_pool_id
        # The name of the resource type.
        self.node_type_name = node_type_name
        # The number of subscription resources that are in use.
        self.node_used = node_used
        # The schedules of the scaling policy.
        self.recurrence_schedules = recurrence_schedules
        # The duration for which no session is connected. Unit: minutes. If no session is connected in the resources after the specified duration elapses, automatic scale-in is triggered. Default value: 5.
        self.scaling_down_after_idle_minutes = scaling_down_after_idle_minutes
        # The total number of scalable resources.
        self.scaling_node_amount = scaling_node_amount
        # The number of scalable resources that are in use.
        self.scaling_node_used = scaling_node_used
        # The number of resources that are created each time resources are scaled out. Valid values: 1 to 10.
        self.scaling_step = scaling_step
        # The upper limit of session usage. If the session usage exceeds the specified upper limit, auto scaling is automatically triggered. The session usage is calculated by using the following formula: `Session usage = Number of current sessions/(Total number of resources × Number of concurrent sessions) × 100%`.
        self.scaling_usage_threshold = scaling_usage_threshold
        # The expiration date of the scaling policy. Format: yyyy-MM-dd.
        self.strategy_disable_date = strategy_disable_date
        # The effective date of the scaling policy. Format: yyyy-MM-dd.
        self.strategy_enable_date = strategy_enable_date
        # The type of the scaling policy.
        # 
        # >  `NODE_SCALING_BY_USAGE` is returned for this parameter only if ChargeType is set to `PrePaid`. `NODE_SCALING_BY_SCHEDULE` is returned for this parameter only if ChargeType is set to `PostPaid`.
        # 
        # Valid values:
        # 
        # *   NODE_FIXED: No scalable resources are used.
        # *   NODE_SCALING_BY_SCHEDULE: Scheduled scaling is used.
        # *   NODE_SCALING_BY_USAGE: Resources are scaled based on usage.
        self.strategy_type = strategy_type
        # Indicates whether the warmup policy is enabled for resources.
        self.warm_up = warm_up

    def validate(self):
        if self.recurrence_schedules:
            for v1 in self.recurrence_schedules:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.amount is not None:
            result['Amount'] = self.amount

        if self.max_idle_app_instance_amount is not None:
            result['MaxIdleAppInstanceAmount'] = self.max_idle_app_instance_amount

        if self.max_scaling_amount is not None:
            result['MaxScalingAmount'] = self.max_scaling_amount

        if self.node_amount is not None:
            result['NodeAmount'] = self.node_amount

        if self.node_capacity is not None:
            result['NodeCapacity'] = self.node_capacity

        if self.node_instance_type is not None:
            result['NodeInstanceType'] = self.node_instance_type

        if self.node_pool_id is not None:
            result['NodePoolId'] = self.node_pool_id

        if self.node_type_name is not None:
            result['NodeTypeName'] = self.node_type_name

        if self.node_used is not None:
            result['NodeUsed'] = self.node_used

        result['RecurrenceSchedules'] = []
        if self.recurrence_schedules is not None:
            for k1 in self.recurrence_schedules:
                result['RecurrenceSchedules'].append(k1.to_map() if k1 else None)

        if self.scaling_down_after_idle_minutes is not None:
            result['ScalingDownAfterIdleMinutes'] = self.scaling_down_after_idle_minutes

        if self.scaling_node_amount is not None:
            result['ScalingNodeAmount'] = self.scaling_node_amount

        if self.scaling_node_used is not None:
            result['ScalingNodeUsed'] = self.scaling_node_used

        if self.scaling_step is not None:
            result['ScalingStep'] = self.scaling_step

        if self.scaling_usage_threshold is not None:
            result['ScalingUsageThreshold'] = self.scaling_usage_threshold

        if self.strategy_disable_date is not None:
            result['StrategyDisableDate'] = self.strategy_disable_date

        if self.strategy_enable_date is not None:
            result['StrategyEnableDate'] = self.strategy_enable_date

        if self.strategy_type is not None:
            result['StrategyType'] = self.strategy_type

        if self.warm_up is not None:
            result['WarmUp'] = self.warm_up

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Amount') is not None:
            self.amount = m.get('Amount')

        if m.get('MaxIdleAppInstanceAmount') is not None:
            self.max_idle_app_instance_amount = m.get('MaxIdleAppInstanceAmount')

        if m.get('MaxScalingAmount') is not None:
            self.max_scaling_amount = m.get('MaxScalingAmount')

        if m.get('NodeAmount') is not None:
            self.node_amount = m.get('NodeAmount')

        if m.get('NodeCapacity') is not None:
            self.node_capacity = m.get('NodeCapacity')

        if m.get('NodeInstanceType') is not None:
            self.node_instance_type = m.get('NodeInstanceType')

        if m.get('NodePoolId') is not None:
            self.node_pool_id = m.get('NodePoolId')

        if m.get('NodeTypeName') is not None:
            self.node_type_name = m.get('NodeTypeName')

        if m.get('NodeUsed') is not None:
            self.node_used = m.get('NodeUsed')

        self.recurrence_schedules = []
        if m.get('RecurrenceSchedules') is not None:
            for k1 in m.get('RecurrenceSchedules'):
                temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules()
                self.recurrence_schedules.append(temp_model.from_map(k1))

        if m.get('ScalingDownAfterIdleMinutes') is not None:
            self.scaling_down_after_idle_minutes = m.get('ScalingDownAfterIdleMinutes')

        if m.get('ScalingNodeAmount') is not None:
            self.scaling_node_amount = m.get('ScalingNodeAmount')

        if m.get('ScalingNodeUsed') is not None:
            self.scaling_node_used = m.get('ScalingNodeUsed')

        if m.get('ScalingStep') is not None:
            self.scaling_step = m.get('ScalingStep')

        if m.get('ScalingUsageThreshold') is not None:
            self.scaling_usage_threshold = m.get('ScalingUsageThreshold')

        if m.get('StrategyDisableDate') is not None:
            self.strategy_disable_date = m.get('StrategyDisableDate')

        if m.get('StrategyEnableDate') is not None:
            self.strategy_enable_date = m.get('StrategyEnableDate')

        if m.get('StrategyType') is not None:
            self.strategy_type = m.get('StrategyType')

        if m.get('WarmUp') is not None:
            self.warm_up = m.get('WarmUp')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedules(DaraModel):
    def __init__(
        self,
        recurrence_type: str = None,
        recurrence_values: List[int] = None,
        timer_periods: List[main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods] = None,
    ):
        # The schedule type of the scaling policy. This parameter must be configured together with `RecurrenceValues`.``
        self.recurrence_type = recurrence_type
        # The days of each week on which the scaling policy is executed.
        self.recurrence_values = recurrence_values
        # The time periods during which the scaling policy can be executed.
        self.timer_periods = timer_periods

    def validate(self):
        if self.timer_periods:
            for v1 in self.timer_periods:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.recurrence_type is not None:
            result['RecurrenceType'] = self.recurrence_type

        if self.recurrence_values is not None:
            result['RecurrenceValues'] = self.recurrence_values

        result['TimerPeriods'] = []
        if self.timer_periods is not None:
            for k1 in self.timer_periods:
                result['TimerPeriods'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RecurrenceType') is not None:
            self.recurrence_type = m.get('RecurrenceType')

        if m.get('RecurrenceValues') is not None:
            self.recurrence_values = m.get('RecurrenceValues')

        self.timer_periods = []
        if m.get('TimerPeriods') is not None:
            for k1 in m.get('TimerPeriods'):
                temp_model = main_models.GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods()
                self.timer_periods.append(temp_model.from_map(k1))

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsNodePoolRecurrenceSchedulesTimerPeriods(DaraModel):
    def __init__(
        self,
        amount: int = None,
        end_time: str = None,
        start_time: str = None,
    ):
        # The number of destination resources.
        self.amount = amount
        # The end time of the scaling policy. Format: HH:mm.
        self.end_time = end_time
        # The start time of the scaling policy. Format: HH:mm.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.amount is not None:
            result['Amount'] = self.amount

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Amount') is not None:
            self.amount = m.get('Amount')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self

class GetAppInstanceGroupResponseBodyAppInstanceGroupModelsApps(DaraModel):
    def __init__(
        self,
        app_icon: str = None,
        app_id: str = None,
        app_name: str = None,
        app_version: str = None,
        app_version_name: str = None,
    ):
        # The application icon.
        self.app_icon = app_icon
        # The application ID.
        self.app_id = app_id
        # The application name.
        self.app_name = app_name
        # The application version.
        self.app_version = app_version
        # The name of the application version.
        self.app_version_name = app_version_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_icon is not None:
            result['AppIcon'] = self.app_icon

        if self.app_id is not None:
            result['AppId'] = self.app_id

        if self.app_name is not None:
            result['AppName'] = self.app_name

        if self.app_version is not None:
            result['AppVersion'] = self.app_version

        if self.app_version_name is not None:
            result['AppVersionName'] = self.app_version_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppIcon') is not None:
            self.app_icon = m.get('AppIcon')

        if m.get('AppId') is not None:
            self.app_id = m.get('AppId')

        if m.get('AppName') is not None:
            self.app_name = m.get('AppName')

        if m.get('AppVersion') is not None:
            self.app_version = m.get('AppVersion')

        if m.get('AppVersionName') is not None:
            self.app_version_name = m.get('AppVersionName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyWuyingServerAttributeRequest(DaraModel):
    def __init__(
        self,
        password: str = None,
        wuying_server_id: str = None,
        wuying_server_name: str = None,
    ):
        # Workstation login password.
        self.password = password
        # The ID of the workstation.
        self.wuying_server_id = wuying_server_id
        # The name.
        self.wuying_server_name = wuying_server_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.password is not None:
            result['Password'] = self.password

        if self.wuying_server_id is not None:
            result['WuyingServerId'] = self.wuying_server_id

        if self.wuying_server_name is not None:
            result['WuyingServerName'] = self.wuying_server_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Password') is not None:
            self.password = m.get('Password')

        if m.get('WuyingServerId') is not None:
            self.wuying_server_id = m.get('WuyingServerId')

        if m.get('WuyingServerName') is not None:
            self.wuying_server_name = m.get('WuyingServerName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListTagCloudResourcesResponseBody(DaraModel):
    def __init__(
        self,
        next_token: str = None,
        request_id: str = None,
        resource_tags: List[main_models.ListTagCloudResourcesResponseBodyResourceTags] = None,
        total_count: int = None,
    ):
        # Indicates whether the next query is required.
        self.next_token = next_token
        # The request ID.
        self.request_id = request_id
        # The tags added to the cloud resources.
        self.resource_tags = resource_tags
        # The total number of entries.
        self.total_count = total_count

    def validate(self):
        if self.resource_tags:
            for v1 in self.resource_tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.next_token is not None:
            result['NextToken'] = self.next_token

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        result['ResourceTags'] = []
        if self.resource_tags is not None:
            for k1 in self.resource_tags:
                result['ResourceTags'].append(k1.to_map() if k1 else None)

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NextToken') is not None:
            self.next_token = m.get('NextToken')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        self.resource_tags = []
        if m.get('ResourceTags') is not None:
            for k1 in m.get('ResourceTags'):
                temp_model = main_models.ListTagCloudResourcesResponseBodyResourceTags()
                self.resource_tags.append(temp_model.from_map(k1))

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListTagCloudResourcesResponseBodyResourceTags(DaraModel):
    def __init__(
        self,
        resource_id: str = None,
        resource_type: str = None,
        tags: List[main_models.ListTagCloudResourcesResponseBodyResourceTagsTags] = None,
    ):
        # The resource ID.
        self.resource_id = resource_id
        # The type of the cloud resource.
        # 
        # Valid values:
        # 
        # *   AppId: app ID.
        # *   WyId: Alibaba Cloud Workspace user ID.
        # *   AppInstanceGroupId: delivery group ID.
        # *   AliUid: tenant ID.
        self.resource_type = resource_type
        # The tags.
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.ListTagCloudResourcesResponseBodyResourceTagsTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class ListTagCloudResourcesResponseBodyResourceTagsTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        scope: str = None,
        value: str = None,
    ):
        # The tag key.
        self.key = key
        # The tag type.
        # 
        # Valid values:
        # 
        # *   Custom: custom tag.
        # *   System: system tag.
        self.scope = scope
        # The tag value.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.scope is not None:
            result['Scope'] = self.scope

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Scope') is not None:
            self.scope = m.get('Scope')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class UntagCloudResourcesRequest(DaraModel):
    def __init__(
        self,
        resource_ids: List[str] = None,
        resource_type: str = None,
        tag_keys: List[str] = None,
    ):
        # The resource IDs. You can specify up to 50 resource IDs. You do not need to specify this parameter if you set ResourceType to AliUid.
        self.resource_ids = resource_ids
        # The type of the resource from which you want to remove tags.
        # 
        # Valid values:
        # 
        # *   AppId: app ID.
        # *   WyId: Alibaba Cloud Workspace user ID.
        # *   AppInstanceGroupId: delivery group ID.
        # *   AliUid: tenant ID.
        # 
        # This parameter is required.
        self.resource_type = resource_type
        # The tags that you want to remove from the cloud resources. System and custom tags are supported. You can specify up to 10 tags.
        # 
        # Valid values for system tags:
        # 
        # *   `System/Scheduler/GRAYSCALE`: canary tags.
        # *   `System/Scheduler/STOP_NEW_USER_CONNECTION`: tags used to stop new users bound to the delivery group from establishing a connection.
        # 
        # This parameter is required.
        self.tag_keys = tag_keys

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_ids is not None:
            result['ResourceIds'] = self.resource_ids

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        if self.tag_keys is not None:
            result['TagKeys'] = self.tag_keys

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ResourceIds') is not None:
            self.resource_ids = m.get('ResourceIds')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        if m.get('TagKeys') is not None:
            self.tag_keys = m.get('TagKeys')

        return self

